package com.ruoyi.attendance.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.ruoyi.attendance.domain.AttendanceClock;
import com.ruoyi.attendance.service.IAttendanceClockService;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;
import org.springframework.web.multipart.MultipartFile;

/**
 * 考勤打卡Controller
 * 
 * @author ruoyi
 * @date 2025-03-04
 */
@RestController
@RequestMapping("/psa/clock")
public class AttendanceClockController extends BaseController
{
    @Autowired
    private IAttendanceClockService attendanceClockService;

    /**
     * 查询考勤打卡列表
     */
    @PreAuthorize("@ss.hasPermi('psa:clock:list')")
    @GetMapping("/list")
    public TableDataInfo list(AttendanceClock attendanceClock)
    {
        startPage();
        List<AttendanceClock> list = attendanceClockService.selectAttendanceClockList(attendanceClock);
        return getDataTable(list);
    }
    /**
     * 查询草稿箱列表
     */
    @PreAuthorize("@ss.hasPermi('psa:clock:draft')")
    @GetMapping("/draft")
    public TableDataInfo listDraft(AttendanceClock attendanceClock)
    {
        startPage();
        List<AttendanceClock> list = attendanceClockService.selectAttendanceClockDraftList(attendanceClock);
        return getDataTable(list);
    }
    /**
     * 导出考勤打卡列表
     */
    @PreAuthorize("@ss.hasPermi('psa:clock:export')")
    @Log(title = "考勤打卡", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, AttendanceClock attendanceClock)
    {
        List<AttendanceClock> list = attendanceClockService.selectAttendanceClockList(attendanceClock);
        ExcelUtil<AttendanceClock> util = new ExcelUtil<AttendanceClock>(AttendanceClock.class);
        util.exportExcel(response, list, "考勤打卡数据");
    }
    /**
     * 导入考勤打卡列表
     */
    @PreAuthorize("@ss.hasPermi('psa:clock:import')")
    @Log(title = "考勤打卡", businessType = BusinessType.IMPORT)
    @PostMapping("/import")
    public AjaxResult importList(@RequestParam("file") MultipartFile file)
    {
        try {
            attendanceClockService.importAttendanceData(file);
            return success("Excel导入成功！");
        } catch (Exception e) {
            return error("导入失败:"+e.getMessage());
        }
    }

    /**
     * 获取考勤打卡详细信息
     */
    @PreAuthorize("@ss.hasPermi('psa:clock:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(attendanceClockService.selectAttendanceClockById(id));
    }

    /**
     * 新增考勤打卡
     */
    @PreAuthorize("@ss.hasPermi('psa:clock:add')")
    @Log(title = "考勤打卡", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody AttendanceClock attendanceClock)
    {
        return toAjax(attendanceClockService.insertAttendanceClock(attendanceClock));
    }
    /**
     * 保存到草稿箱
     */
    @PreAuthorize("@ss.hasPermi('psa:clock:draft')")
    @Log(title = "考勤打卡", businessType = BusinessType.INSERT)
    @PostMapping("/draft")
    public AjaxResult addDraft(@RequestBody AttendanceClock attendanceClock)
    {
        return toAjax(attendanceClockService.insertAttendanceClockDraft(attendanceClock));
    }

    /**
     * 修改考勤打卡
     */
    @PreAuthorize("@ss.hasPermi('psa:clock:edit')")
    @Log(title = "考勤打卡", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody AttendanceClock attendanceClock)
    {
        return toAjax(attendanceClockService.updateAttendanceClock(attendanceClock));
    }

    /**
     * 删除考勤打卡
     */
    @PreAuthorize("@ss.hasPermi('psa:clock:remove')")
    @Log(title = "考勤打卡", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(attendanceClockService.deleteAttendanceClockByIds(ids));
    }
}
