package com.ruoyi.attendance.service.impl;

import java.io.IOException;
import java.io.InputStream;
import java.time.LocalDate;
import java.time.LocalDateTime;
import java.time.LocalTime;
import java.time.format.DateTimeFormatter;
import java.util.*;

import com.alibaba.excel.EasyExcel;
import com.alibaba.excel.ExcelReader;
import com.alibaba.excel.context.AnalysisContext;
import com.alibaba.excel.metadata.data.ReadCellData;
import com.alibaba.excel.read.listener.ReadListener;
import com.alibaba.excel.read.metadata.ReadSheet;
import com.ruoyi.attendance.domain.AttendanceClock;
import com.ruoyi.attendance.enums.AttendanceDelFlag;
import com.ruoyi.attendance.enums.AttendanceDraft;
import com.ruoyi.attendance.enums.AttendanceStatus;
import com.ruoyi.attendance.enums.AttendanceTimeDifference;
import com.ruoyi.attendance.mapper.AttendanceClockMapper;
import com.ruoyi.attendance.service.IAttendanceClockService;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.common.utils.SecurityUtils;
import com.ruoyi.common.utils.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.web.multipart.MultipartFile;


/**
 * 考勤打卡Service业务层处理
 * 
 * @author ruoyi
 * @date 2025-03-04
 */
@Service
public class AttendanceClockServiceImpl implements IAttendanceClockService
{
    @Autowired
    private AttendanceClockMapper attendanceClockMapper;

    /**
     * 查询考勤打卡
     * 
     * @param id 考勤打卡主键
     * @return 考勤打卡
     */
    @Override
    public AttendanceClock selectAttendanceClockById(Long id)
    {
        return attendanceClockMapper.selectAttendanceClockById(id);
    }

    /**
     * 查询考勤打卡列表
     * 
     * @param attendanceClock 考勤打卡
     * @return 考勤打卡
     */
    @Override
    public List<AttendanceClock> selectAttendanceClockList(AttendanceClock attendanceClock)
    {
        attendanceClock.setDelFlag(AttendanceDelFlag.EXIST.getValue());
        attendanceClock.setDraft(AttendanceDraft.NO.getValue());
        return attendanceClockMapper.selectAttendanceClockList(attendanceClock);
    }
    /**
     * 查询草稿列表
     *
     * @param attendanceClock 考勤打卡
     * @return 考勤打卡
     */
    @Override
    public List<AttendanceClock> selectAttendanceClockDraftList(AttendanceClock attendanceClock) {
        attendanceClock.setDelFlag(AttendanceDelFlag.EXIST.getValue());
        attendanceClock.setDraft(AttendanceDraft.YES.getValue());
        return attendanceClockMapper.selectAttendanceClockList(attendanceClock);
    }

    /**
     * 新增考勤打卡
     * 
     * @param attendanceClock 考勤打卡
     * @return 结果
     */

    @Override
    public int insertAttendanceClock(AttendanceClock attendanceClock)
    {
        attendanceClock.setCheckInStatus(isStatus(attendanceClock.getIsClock(),attendanceClock.getClockTime()));
        attendanceClock.setCreatBy(SecurityUtils.getLoginUser().getUsername());
        attendanceClock.setCreatTime(LocalDateTime.now());
        attendanceClock.setDraft(AttendanceDraft.NO.getValue());
        attendanceClock.setDelFlag(AttendanceDelFlag.EXIST.getValue());
        return attendanceClockMapper.insertAttendanceClock(attendanceClock);
    }
    /**
     * 保存到草稿箱
     *
     * @param attendanceClock 考勤打卡
     * @return 结果
     */
    @Override
    public int insertAttendanceClockDraft(AttendanceClock attendanceClock) {
        attendanceClock.setCreatBy(SecurityUtils.getLoginUser().getUsername());
        attendanceClock.setCreatTime(LocalDateTime.now());
        attendanceClock.setDelFlag(AttendanceDelFlag.EXIST.getValue());
        attendanceClock.setDraft(AttendanceDraft.YES.getValue());
        attendanceClock.setCheckInStatus(isStatus(attendanceClock.getIsClock(),attendanceClock.getClockTime()));
        return attendanceClockMapper.insertAttendanceClock(attendanceClock);

    }

    /**
     * 修改考勤打卡
     * 
     * @param attendanceClock 考勤打卡
     * @return 结果
     */
    @Override
    public int updateAttendanceClock(AttendanceClock attendanceClock)
    {
        if (attendanceClock.getDraft().equals(AttendanceDraft.YES.getValue())){
            attendanceClock.setDraft(AttendanceDraft.NO.getValue());
        }
        attendanceClock.setUpdateTime(DateUtils.getNowDate());
        attendanceClock.setCheckInStatus(isStatus(attendanceClock.getIsClock(),attendanceClock.getClockTime()));
        return attendanceClockMapper.updateAttendanceClock(attendanceClock);

    }

    /**
     * 批量删除考勤打卡
     * 
     * @param ids 需要删除的考勤打卡主键
     * @return 结果
     */
    @Override
    public int deleteAttendanceClockByIds(Long[] ids)
    {
        return attendanceClockMapper.deleteAttendanceClockByIds(ids);
    }

    /**
     * 删除考勤打卡信息
     * 
     * @param id 考勤打卡主键
     * @return 结果
     */
    @Override
    public int deleteAttendanceClockById(Long id)
    {
        return attendanceClockMapper.deleteAttendanceClockById(id);
    }

    /**
     * Excel导入
     * @param file 导入文件
     *
     */
    @Override
    @Transactional(rollbackFor = Exception.class)
    public void importAttendanceData(MultipartFile file) throws IOException {
        try (InputStream inputStream = file.getInputStream()) {
            // 读取 Excel，检查 Sheet 名称
            ExcelReader excelReader = EasyExcel.read(inputStream).build();
            ReadSheet targetSheet = null;
            for (ReadSheet sheet : excelReader.excelExecutor().sheetList()) {
                if ("考勤记录".equals(sheet.getSheetName())) {
                    targetSheet = sheet;
                    break;
                }
            }
            if (targetSheet == null) {
                throw new RuntimeException("Excel 文件中未找到名为 '考勤记录' 的 Sheet");
            }
            // 重新获取 InputStream 进行实际的读取
            try (InputStream inputStream2 = file.getInputStream()) {
                EasyExcel.read(inputStream2, new ReadListener<Map<Integer, String>>() {
                    private String yearMonth;
                    private final List<AttendanceClock> records = new ArrayList<>();
                    private final Map<Integer, Map<Integer, String>> rowCache = new HashMap<>(); // 存储解析过的行数据

                    @Override
                    public void invoke(Map<Integer, String> rowData, AnalysisContext context) {
                        int rowIndex = context.readRowHolder().getRowIndex();
                        // 解析第三行 C 列的前 7 个字符，作为打卡日期的 yyyy-MM
                        if (rowIndex == 2) {
                            String fullDate = rowData.get(2);
                            if (fullDate != null && fullDate.length() >= 7) {
                                yearMonth = fullDate.substring(0, 7);
                            }
                            return;
                        }
                        // 只解析偶数行
                        if (rowIndex < 5 || rowIndex % 2 == 0) {
                            rowCache.put(rowIndex, rowData); // 存入缓存
                            return;
                        }
                        if (yearMonth == null) {
                            throw new RuntimeException("未能解析到有效的年份-月份");
                        }

                        // 获取当前行的上一行
                        int prevRowIndex = rowIndex - 1;
                        Map<Integer, String> prevRowData = rowCache.get(prevRowIndex);
                        if (prevRowData == null) {
                            throw new RuntimeException("无法获取上一行数据");
                        }
                        String employeeId = prevRowData.get(2); //           C列工号ID
                        String employeeName = prevRowData.get(10); //        K列员工姓名
                        String departmentName = prevRowData.get(20); //      U列部门名称
                        // 跳过空的单元格
                        for (int colIndex = 0; colIndex < rowData.size(); colIndex++) {
                            String timeStr = rowData.get(colIndex);
                            if (StringUtils.isBlank(timeStr)) continue;

                            String day = String.format("%02d", colIndex + 1);
                            String fullDate = yearMonth + "-" + day;
                            LocalDate checkDate = LocalDate.parse(fullDate);

                            // 解析打卡时间
                            for (int i = 0; i < timeStr.length(); i += 5) {
                                String timePart = timeStr.substring(i, i + 5);
                                LocalTime checkTime = LocalTime.parse(timePart, DateTimeFormatter.ofPattern("HH:mm"));

                                AttendanceClock record = new AttendanceClock();
                                record.setEmployeeId(employeeId);
                                record.setCandidateDate(checkDate);
                                record.setClockTime(checkTime);
                                record.setIsClock(isClock(checkTime));
                                record.setEmployeeName(employeeName);
                                record.setCheckInStatus(isStatus(record.getIsClock(),record.getClockTime()));
                                record.setDepartmentName(departmentName);
                                record.setCreatBy(SecurityUtils.getLoginUser().getUsername());
                                record.setCreatTime(LocalDateTime.now());
                                record.setDraft(AttendanceDraft.NO.getValue());
                                record.setDelFlag(AttendanceDelFlag.EXIST.getValue());
                                records.add(record);
                            }
                        }
                    }

                    @Override
                    public void doAfterAllAnalysed(AnalysisContext context) {
                        if (!records.isEmpty()) {
                            attendanceClockMapper.batchInsertAttendanceClock(records);
                        }
                        rowCache.clear(); // 释放内存
                    }
                }).sheet(targetSheet.getSheetNo()).doRead();
            }
        }
    }

    //判断上下班打卡方法
    public String isClock(LocalTime d){
        LocalTime comparisonTime = LocalTime.parse("13:00");// 如果打卡时间比13:00则为上班时间打卡
        if (d.isBefore(comparisonTime)) {
            return AttendanceTimeDifference.AM.getValue();
        }else {
            return AttendanceTimeDifference.PM.getValue();
        }
    }
    //判断打卡状态方法
    public String isStatus(String d, LocalTime t){
        if (d.equals(AttendanceTimeDifference.AM.getValue())){
            LocalTime comparisonTime = LocalTime.parse("09:15"); // 如果打卡时间比 09:00 早，则正常
            if (t.isBefore(comparisonTime)) {
                return AttendanceStatus.ZCQD.getValue();
            } else {
                return AttendanceStatus.CD.getValue();
            }
        }else{
            LocalTime comparisonTime = LocalTime.parse("17:15"); // 如果打卡时间比 18:00 早，则早退
            if (t.isBefore(comparisonTime)) {
                return AttendanceStatus.ZT.getValue();
            } else {
                return AttendanceStatus.ZCQT.getValue();
            }
        }
    }
}
