package com.ruoyi.controller;

import com.ruoyi.common.annotation.Anonymous;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.domain.FyglDailyReimbursement;
import com.ruoyi.domain.dto.FyglDailyReimbursementDTO;
import com.ruoyi.domain.dto.FyglProjectDTO;
import com.ruoyi.domain.dto.FyglProjectList;
import com.ruoyi.domain.vo.FyglDailyReimbursementVo;
import com.ruoyi.service.IFyglDailyReimbursementService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;

import java.util.List;


/**
 * 日常报销Controller
 * 
 * @author ruoyi
 * @date 2025-02-28
 */
@RestController
@RequestMapping("/dailyReimbursement/dailyReimbursement")
public class FyglDailyReimbursementController extends BaseController
{
    @Autowired
    private IFyglDailyReimbursementService fyglDailyReimbursementService;

    /**
     * 查询日常报销列表
     */
//    @PreAuthorize("@ss.hasPermi('dailyReimbursement:dailyReimbursement:list')")
    @GetMapping("/list")
    public TableDataInfo list(FyglDailyReimbursementVo fyglDailyReimbursementVO)
    {
        startPage();
        List<FyglDailyReimbursementDTO> list = fyglDailyReimbursementService.selectFyglDailyReimbursementList(fyglDailyReimbursementVO);
        return getDataTable(list);
    }


    //根据当前用户角色id，查询所有项目关联的项目-最新
    @GetMapping("/getProjectListByUserId")
    public AjaxResult getProjectListByUserId(FyglDailyReimbursementVo fyglDailyReimbursementVO)
    {
        List<FyglDailyReimbursementDTO> projectList = fyglDailyReimbursementService.getProjectListByUserId(fyglDailyReimbursementVO);
        return AjaxResult.success(projectList);
    }



    //获取所有项目名字和id,用于搜索
    @GetMapping("/projectList")
    public AjaxResult projectList()
    {
        List<FyglProjectList> projectList = fyglDailyReimbursementService.getProjectList();
        return AjaxResult.success(projectList);
    }
    //获取所有项目名字和id
    @GetMapping("/projectDetail/{id}")
    public AjaxResult projectList(@PathVariable("id") Long id)
    {
        FyglProjectDTO projectDetail = fyglDailyReimbursementService.getProjectDetail(id);
        return AjaxResult.success(projectDetail);
    }
    /**
     * 导出日常报销列表
     */
//    @PreAuthorize("@ss.hasPermi('dailyReimbursement:dailyReimbursement:export')")
//    @Log(title = "日常报销", businessType = BusinessType.EXPORT)
//    @PostMapping("/export")
//    public void export(HttpServletResponse response, FyglDailyReimbursement fyglDailyReimbursement)
//    {
//        List<FyglDailyReimbursement> list = fyglDailyReimbursementService.selectFyglDailyReimbursementList(fyglDailyReimbursement);
//        ExcelUtil<FyglDailyReimbursement> util = new ExcelUtil<FyglDailyReimbursement>(FyglDailyReimbursement.class);
//        util.exportExcel(response, list, "日常报销数据");
//    }

    /**
     * 获取日常报销详细信息
     */
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(fyglDailyReimbursementService.selectFyglDailyReimbursementById(id));
    }

    /**
     * 新增日常报销
     */
//    @PreAuthorize("@ss.hasPermi('dailyReimbursement:dailyReimbursement:add')")
    @Log(title = "日常报销", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody FyglDailyReimbursement fyglDailyReimbursement)
    {
        System.out.println("新增对象 = " + fyglDailyReimbursement);
        return toAjax(fyglDailyReimbursementService.insertFyglDailyReimbursement(fyglDailyReimbursement));
    }

    /**
     * 修改日常报销
     */
    @Log(title = "日常报销", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody FyglDailyReimbursement fyglDailyReimbursement)
    {
        return toAjax(fyglDailyReimbursementService.updateFyglDailyReimbursement(fyglDailyReimbursement));
    }

    /**
     * 删除日常报销
     */
    @PreAuthorize("@ss.hasPermi('dailyReimbursement:dailyReimbursement:remove')")
    @Log(title = "日常报销", businessType = BusinessType.DELETE)
	@DeleteMapping("/{id}")
    public AjaxResult remove(@PathVariable Long id)
    {
        return toAjax(fyglDailyReimbursementService.deleteFyglDailyReimbursementById(id));
    }
}
