package com.ruoyi.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.ruoyi.common.utils.spring.SpringUtils;
import com.ruoyi.domain.dto.BatchUpdateDTO;
import com.ruoyi.domain.dto.EmployeeBalanceDTO;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.domain.LeaveApplication;
import com.ruoyi.service.ILeaveApplicationService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 请假申请Controller
 * 
 * @author hht
 * @date 2025-03-03
 */
@RestController
@RequestMapping("/application/application")
public class LeaveApplicationController extends BaseController
{
    @Autowired
    private ILeaveApplicationService leaveApplicationService;
    @Autowired
    private SpringUtils springUtils;

    /**
     * 查询请假申请列表
     */
    @PreAuthorize("@ss.hasPermi('application:application:list')")
    @GetMapping("/list")
    public TableDataInfo list(LeaveApplication leaveApplication)
    {
        startPage();
        List<LeaveApplication> list = leaveApplicationService.selectLeaveApplicationList(leaveApplication);
        return getDataTable(list);
    }

    /**
     * 导出请假申请列表
     */
    @PreAuthorize("@ss.hasPermi('application:application:export')")
    @Log(title = "请假申请", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, LeaveApplication leaveApplication)
    {
        List<LeaveApplication> list = leaveApplicationService.selectLeaveApplicationList(leaveApplication);
        ExcelUtil<LeaveApplication> util = new ExcelUtil<LeaveApplication>(LeaveApplication.class);
        util.exportExcel(response, list, "请假申请数据");
    }

    /**
     * 获取请假申请详细信息
     */
    @PreAuthorize("@ss.hasPermi('application:application:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(leaveApplicationService.selectLeaveApplicationById(id));
    }

    /**
     * 新增请假申请
     */
    @PreAuthorize("@ss.hasPermi('application:application:add')")
    @Log(title = "请假申请", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody LeaveApplication leaveApplication)
    {
        return toAjax(leaveApplicationService.insertLeaveApplication(leaveApplication));
    }

    /**
     * 修改请假申请
     */
    @PreAuthorize("@ss.hasPermi('application:application:edit')")
    @Log(title = "请假申请", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody LeaveApplication leaveApplication)
    {
        return toAjax(leaveApplicationService.updateLeaveApplication(leaveApplication));
    }

    /**
     * 删除请假申请
     */
    @PreAuthorize("@ss.hasPermi('application:application:remove')")
    @Log(title = "请假申请", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(leaveApplicationService.deleteLeaveApplicationByIds(ids));
    }

    /**
     * 根据用户ID查询可抵扣的加班时长
     * @param userId
     * @return
     */
    @GetMapping("/deductionOvertimeHours")
    public EmployeeBalanceDTO selectDeductionOvertimeHoursByUserId(@RequestParam Long userId) {
        return leaveApplicationService.selectDeductionOvertimeHoursByUserId(userId);
    }


    /**
     * 更新员工的加班小时数余额
     * @param dto 包含加班小时数余额和员工ID的DTO对象
     * @return 更新结果
     */
    @Log(title = "请假申请", businessType = BusinessType.UPDATE)
    @PutMapping("/updateOvertimeHoursBalance")
    public AjaxResult updateOvertimeHoursBalance(@RequestBody EmployeeBalanceDTO dto) {
        System.out.println("前端接受的加班小时数余额信息："+dto);
        return toAjax(leaveApplicationService.updateOvertimeHoursBalance(dto));
    }

    @GetMapping("/project-managers")
    public List<String> getProjectManagers() {
        return leaveApplicationService.selectProjectManagers();
    }


    /**
     * 获取总经理的nick_name
     */
    @GetMapping("/general-manager")
    public AjaxResult getGeneralManagerNickName() {
        String generalManagerNickName = leaveApplicationService.selectGeneralManagerNickName();
        return AjaxResult.success(generalManagerNickName);
    }


    @PutMapping("/updateNodeAndApprovalStatus")
    public void batchUpdateNodeAndApprovalStatus(@RequestBody BatchUpdateDTO dto) {
        System.out.println("前端传过来的数据："+dto);
        leaveApplicationService.batchUpdateNodeIdAndApprovalStatus(dto);
    }
}
