package com.ruoyi.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.ruoyi.domain.dto.OvertimeApplicationBatchDTO;
import com.ruoyi.domain.vo.ProjectEmployeeInfoVo;
import com.ruoyi.service.IProjectEmployeeInfoService;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.domain.OvertimeApplication;
import com.ruoyi.service.IOvertimeApplicationService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 加班申请Controller
 *
 * @author hht
 * @date 2025-03-06
 */
@RestController
@RequestMapping("/application/overtimeApplication")
public class OvertimeApplicationController extends BaseController {
    @Autowired
    private IOvertimeApplicationService overtimeApplicationService;
    @Autowired
    private IProjectEmployeeInfoService projectEmployeeInfoService;

    /**
     * 查询加班申请列表
     */
    @PreAuthorize("@ss.hasPermi('application:overtimeApplication:list')")
    @GetMapping("/list")
    public TableDataInfo list(OvertimeApplication overtimeApplication) {
        startPage();
        List<OvertimeApplication> list = overtimeApplicationService.selectOvertimeApplicationList(overtimeApplication);
        return getDataTable(list);
    }

    /**
     * 查询加班申请信息
     */
    @GetMapping("/find")
    public AjaxResult getProjectEmployeeInfo(@RequestParam String projectManagerNickName) {
        List<ProjectEmployeeInfoVo> projectEmployeeInfoList = projectEmployeeInfoService.getProjectEmployeeInfo(projectManagerNickName);
        return success(projectEmployeeInfoList);
    }

    /**
     * 导出加班申请列表
     */
    @PreAuthorize("@ss.hasPermi('application:overtimeApplication:export')")
    @Log(title = "加班申请", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, OvertimeApplication overtimeApplication) {
        List<OvertimeApplication> list = overtimeApplicationService.selectOvertimeApplicationList(overtimeApplication);
        ExcelUtil<OvertimeApplication> util = new ExcelUtil<OvertimeApplication>(OvertimeApplication.class);
        util.exportExcel(response, list, "加班申请数据");
    }

    /**
     * 获取加班申请详细信息
     */
    @PreAuthorize("@ss.hasPermi('application:overtimeApplication:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return success(overtimeApplicationService.selectOvertimeApplicationById(id));
    }

    /**
     * 新增加班申请
     */
    @PreAuthorize("@ss.hasPermi('application:overtimeApplication:add')")
    @Log(title = "加班申请", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody OvertimeApplication overtimeApplication) {
        return toAjax(overtimeApplicationService.insertOvertimeApplication(overtimeApplication));
    }

    /**
     * 批量新增加班申请
     */
    @PreAuthorize("@ss.hasPermi('application:overtimeApplication:add')")
    @Log(title = "加班申请(批量)", businessType = BusinessType.INSERT)
    @PostMapping("/batch")
    public AjaxResult addBatch(@RequestBody OvertimeApplicationBatchDTO batchRequest) {
        // 调用 Service 层方法，批量插入
        System.out.println("批量插入的数据:"+batchRequest);
        int rows = overtimeApplicationService.insertOvertimeApplicationBatch(batchRequest);
        return toAjax(rows);
    }

    /**
     * 修改加班申请
     */
    @PreAuthorize("@ss.hasPermi('application:overtimeApplication:edit')")
    @Log(title = "加班申请", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody OvertimeApplication overtimeApplication) {
        return toAjax(overtimeApplicationService.updateOvertimeApplication(overtimeApplication));
    }

    /**
     * 删除加班申请
     */
    @PreAuthorize("@ss.hasPermi('application:overtimeApplication:remove')")
    @Log(title = "加班申请", businessType = BusinessType.DELETE)
    @DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(overtimeApplicationService.deleteOvertimeApplicationByIds(ids));
    }
}
