package com.ruoyi.employment.controller;

import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.employment.domain.ApprovalInstance;
import com.ruoyi.employment.service.IApprovalInstanceService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * 人事管理审批关联Controller
 *
 * @author ruoyi
 * @date 2025-03-25
 */
@RestController
@RequestMapping("/system/instance")
public class ApprovalInstanceController extends BaseController
{
    @Autowired
    private IApprovalInstanceService approvalInstanceService;

    /**
     * 查询人事管理审批关联列表
     */
    @PreAuthorize("@ss.hasPermi('system:instance:list')")
    @GetMapping("/list")
    public TableDataInfo list(ApprovalInstance approvalInstance)
    {
        startPage();
        List<ApprovalInstance> list = approvalInstanceService.selectApprovalInstanceList(approvalInstance);
        return getDataTable(list);
    }

    /**
     * 导出人事管理审批关联列表
     */
    @PreAuthorize("@ss.hasPermi('system:instance:export')")
    @Log(title = "人事管理审批关联", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, ApprovalInstance approvalInstance)
    {
        List<ApprovalInstance> list = approvalInstanceService.selectApprovalInstanceList(approvalInstance);
        ExcelUtil<ApprovalInstance> util = new ExcelUtil<ApprovalInstance>(ApprovalInstance.class);
        util.exportExcel(response, list, "人事管理审批关联数据");
    }

    /**
     * 获取人事管理审批关联详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:instance:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(approvalInstanceService.selectApprovalInstanceById(id));
    }

    /**
     * 新增人事管理审批关联
     */
    @PreAuthorize("@ss.hasPermi('system:instance:add')")
    @Log(title = "人事管理审批关联", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody ApprovalInstance approvalInstance)
    {
        return toAjax(approvalInstanceService.insertApprovalInstance(approvalInstance));
    }

    /**
     * 修改人事管理审批关联
     */
    @PreAuthorize("@ss.hasPermi('system:instance:edit')")
    @Log(title = "人事管理审批关联", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody ApprovalInstance approvalInstance)
    {
        return toAjax(approvalInstanceService.updateApprovalInstance(approvalInstance));
    }

    /**
     * 删除人事管理审批关联
     */
    @PreAuthorize("@ss.hasPermi('system:instance:remove')")
    @Log(title = "人事管理审批关联", businessType = BusinessType.DELETE)
    @DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(approvalInstanceService.deleteApprovalInstanceByIds(ids));
    }
}