package com.ruoyi.employment.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.employment.domain.EmploymentApproval;
import com.ruoyi.employment.service.IEmploymentApprovalService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;
import org.springframework.web.multipart.MultipartFile;

/**
 * 入职审批Controller
 * 
 * @author ruoyi
 * @date 2025-02-25
 */
@RestController
@RequestMapping("/staffmanage/onboardmanage")
public class EmploymentApprovalController extends BaseController
{
    @Autowired
    private IEmploymentApprovalService employmentApprovalService;

    /**
     * 查询入职审批列表
     */
    //@PreAuthorize("@ss.hasPermi('approval:approval:list')")
    @PreAuthorize("@ss.hasRole('admin') or @ss.hasRole('project-manager') or @ss.hasRole('hr') or @ss.hasRole('general-manager')")
    @GetMapping("/list")
    public TableDataInfo list(EmploymentApproval employmentApproval)
    {
        startPage();
        List<EmploymentApproval> list = employmentApprovalService.selectEmploymentApprovalList(employmentApproval);
        return getDataTable(list);
    }

    /**
     * 导出入职审批列表
     */
    //@PreAuthorize("@ss.hasPermi('approval:approval:export')")
    @PreAuthorize("@ss.hasRole('admin') or @ss.hasRole('project-manager') or @ss.hasRole('hr') or @ss.hasRole('general-manager')")
    @Log(title = "入职审批", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, EmploymentApproval employmentApproval)
    {
        List<EmploymentApproval> list = employmentApprovalService.selectEmploymentApprovalList(employmentApproval);
        ExcelUtil<EmploymentApproval> util = new ExcelUtil<EmploymentApproval>(EmploymentApproval.class);
        util.exportExcel(response, list, "入职审批数据");
    }

    //@PreAuthorize("@ss.hasPermi('approval:approval:import')")
    @PreAuthorize("@ss.hasRole('admin') or @ss.hasRole('project-manager') or @ss.hasRole('hr') or @ss.hasRole('general-manager')")
    @Log(title = "入职审批", businessType = BusinessType.IMPORT)
    @PostMapping("/importData")
    public AjaxResult importData(@RequestParam("file") MultipartFile file) throws Exception {
        // 1. 创建Excel工具类实例
        ExcelUtil<EmploymentApproval> util = new ExcelUtil<>(EmploymentApproval.class);

        // 2. 解析Excel文件，获取实体列表
        List<EmploymentApproval> employmentApprovalList = util.importExcel(file.getInputStream());

        // 3. 调用Service层处理数据
        String result = employmentApprovalService.processImportedData(employmentApprovalList);

        // 4. 返回导入结果
        return AjaxResult.success(result);
    }

    @PostMapping("/importTemplate")
    public void importTemplate(HttpServletResponse response)
    {
        ExcelUtil<EmploymentApproval> util = new ExcelUtil<EmploymentApproval>(EmploymentApproval.class);
        util.importTemplateExcel(response, "用户数据");
    }

    /**
     * 获取入职审批详细信息
     */
    //@PreAuthorize("@ss.hasPermi('approval:approval:query')")
    @PreAuthorize("@ss.hasRole('admin') or @ss.hasRole('project-manager') or @ss.hasRole('hr') or @ss.hasRole('general-manager')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(employmentApprovalService.selectEmploymentApprovalById(id));
    }

    /**
     * 新增入职审批
     */
    //@PreAuthorize("@ss.hasPermi('approval:approval:add')")
    @PreAuthorize("@ss.hasRole('admin') or @ss.hasRole('project-manager') or @ss.hasRole('hr') or @ss.hasRole('general-manager')")
    @Log(title = "入职审批", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody EmploymentApproval employmentApproval)
    {
        return toAjax(employmentApprovalService.insertEmploymentApproval(employmentApproval));
    }

    /**
     * 修改入职审批
     */
    //@PreAuthorize("@ss.hasPermi('approval:approval:edit')")
    @PreAuthorize("@ss.hasRole('admin') or @ss.hasRole('project-manager') or @ss.hasRole('hr') or @ss.hasRole('general-manager')")
    @Log(title = "入职审批", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody EmploymentApproval employmentApproval)
    {
        return toAjax(employmentApprovalService.updateEmploymentApproval(employmentApproval));
    }

    /**
     * 删除入职审批
     */
    //@PreAuthorize("@ss.hasPermi('approval:approval:remove')")
    @PreAuthorize("@ss.hasRole('admin') or @ss.hasRole('project-manager') or @ss.hasRole('hr') or @ss.hasRole('general-manager')")
    @Log(title = "入职审批", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(employmentApprovalService.deleteEmploymentApprovalByIds(ids));
    }




    /**
     * 查询入职审批列表
     */
    //@PreAuthorize("@ss.hasPermi('approval:approval:check')")
    @PreAuthorize("@ss.hasRole('admin') or @ss.hasRole('project-manager') or @ss.hasRole('hr') or @ss.hasRole('general-manager')")
    @GetMapping("/listDraft")
    public TableDataInfo draft(EmploymentApproval employmentApproval)
    {
        startPage();
        List<EmploymentApproval> list = employmentApprovalService.selectEmploymentApprovalDraftList(employmentApproval);
        return getDataTable(list);
    }

    /**
     * 入职草稿箱新增
     */
    //@PreAuthorize("@ss.hasPermi('approval:approval:addDraft')")
    @PreAuthorize("@ss.hasRole('admin') or @ss.hasRole('project-manager') or @ss.hasRole('hr') or @ss.hasRole('general-manager')")
    @Log(title = "入职审批", businessType = BusinessType.INSERT)
    @PostMapping("/addDraft")
    public AjaxResult addDraft(@RequestBody EmploymentApproval employmentApproval)
    {
        return toAjax(employmentApprovalService.insertEmploymentApprovalDraft(employmentApproval));
    }


    /**
     * 入职草稿箱修改
     */
    //@PreAuthorize("@ss.hasPermi('approval:approval:updateDraft')")
    @PreAuthorize("@ss.hasRole('admin') or @ss.hasRole('project-manager') or @ss.hasRole('hr') or @ss.hasRole('general-manager')")
    @Log(title = "入职审批", businessType = BusinessType.UPDATE)
    @PutMapping("/updateDraft")
    public AjaxResult updateDraft(@RequestBody EmploymentApproval employmentApproval)
    {
        return toAjax(employmentApprovalService.updateEmploymentApprovalDraft(employmentApproval));
    }


    @PreAuthorize("@ss.hasRole('admin') or @ss.hasRole('project-manager') or @ss.hasRole('hr') or @ss.hasRole('general-manager')")
    @PostMapping("/updateApproval")
    public AjaxResult updateApproval(@RequestBody EmploymentApproval employmentApproval)
    {
        return toAjax(employmentApprovalService.updateApproval(employmentApproval));
    }

    @PreAuthorize("@ss.hasRole('admin') or @ss.hasRole('project-manager') or @ss.hasRole('hr') or @ss.hasRole('general-manager')")
    @PostMapping("/updateApproval2")
    public AjaxResult updateApproval2(@RequestBody EmploymentApproval employmentApproval)
    {
        return toAjax(employmentApprovalService.updateApproval2(employmentApproval));
    }
    @PreAuthorize("@ss.hasRole('admin') or @ss.hasRole('project-manager') or @ss.hasRole('hr') or @ss.hasRole('general-manager') or @ss.hasRole('common')")
    @GetMapping("/listAll")
    public AjaxResult listAll()
    {
        return AjaxResult.success(employmentApprovalService.getCurrentUserApproval());
    }


    @PreAuthorize("@ss.hasRole('admin') or @ss.hasRole('project-manager') or @ss.hasRole('hr') or @ss.hasRole('general-manager') or @ss.hasRole('common')")
    @GetMapping("/getTodayBirthdayCount")
    public AjaxResult getTodayBirthdayCount()
    {
        return AjaxResult.success(employmentApprovalService.countTodayBirthday());
    }

    @PreAuthorize("@ss.hasRole('admin') or @ss.hasRole('project-manager') or @ss.hasRole('hr') or @ss.hasRole('general-manager') or @ss.hasRole('common')")
    @GetMapping("/getQuarterBirthdayCount")
    public AjaxResult getQuarterBirthdayCount()
    {
        return AjaxResult.success(employmentApprovalService.countCurrentQuarterBirthday());
    }
}
