package com.ruoyi.employment.service.impl;

import java.util.List;

import com.ruoyi.common.core.domain.model.LoginUser;
import com.ruoyi.common.exception.ServiceException;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.common.utils.SecurityUtils;
import com.ruoyi.employment.domain.ApprovalInstance;
import com.ruoyi.employment.domain.dto.EmploymentApprovalDTO;
import com.ruoyi.employment.mapper.ApprovalInstanceMapper;
import org.apache.commons.collections4.CollectionUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.employment.mapper.EmploymentApprovalMapper;
import com.ruoyi.employment.domain.EmploymentApproval;
import com.ruoyi.employment.service.IEmploymentApprovalService;

/**
 * 入职审批Service业务层处理
 * 
 * @author ruoyi
 * @date 2025-02-25
 */
@Service
public class EmploymentApprovalServiceImpl implements IEmploymentApprovalService 
{
    @Autowired
    private EmploymentApprovalMapper employmentApprovalMapper;
    @Autowired
    private ApprovalInstanceMapper approvalInstanceMapper;

    /**
     * 查询入职审批
     * 
     * @param id 入职审批主键
     * @return 入职审批
     */
    @Override
    public EmploymentApproval selectEmploymentApprovalById(Long id)
    {
        return employmentApprovalMapper.selectEmploymentApprovalById(id);
    }

    /**
     * 查询入职审批列表
     * 
     * @param employmentApproval 入职审批
     * @return 入职审批
     */
    @Override
    public List<EmploymentApproval> selectEmploymentApprovalList(EmploymentApproval employmentApproval)
    {
        return employmentApprovalMapper.selectEmploymentApprovalList(employmentApproval);
    }

    /**
     * 新增入职审批
     * 
     * @param employmentApproval 入职审批
     * @return 结果
     */
    @Override
    public int insertEmploymentApproval(EmploymentApproval employmentApproval)
    {
        employmentApprovalMapper.insertEmploymentApproval(employmentApproval);
        ApprovalInstance approvalInstance = employmentApproval.getApprovalInstance();
        approvalInstance.setApid(17);
        approvalInstance.setUserId(employmentApproval.getId());
        approvalInstance.setState(0);
        approvalInstanceMapper.insertApprovalInstance(approvalInstance);
        return 1;
    }

    /**
     * 修改入职审批
     * 
     * @param employmentApproval 入职审批
     * @return 结果
     */
    @Override
    public int updateEmploymentApproval(EmploymentApproval employmentApproval)
    {
        employmentApproval.setUpdateTime(DateUtils.getNowDate());
        return employmentApprovalMapper.updateEmploymentApproval(employmentApproval);
    }

    /**
     * 批量删除入职审批
     * 
     * @param ids 需要删除的入职审批主键
     * @return 结果
     */
    @Override
    public int deleteEmploymentApprovalByIds(Long[] ids)
    {
        return employmentApprovalMapper.deleteEmploymentApprovalByIds(ids);
    }

    /**
     * 删除入职审批信息
     * 
     * @param id 入职审批主键
     * @return 结果
     */
    @Override
    public int deleteEmploymentApprovalById(Long id)
    {
        return employmentApprovalMapper.deleteEmploymentApprovalById(id);
    }

    @Override
    public String processImportedData(List<EmploymentApproval> list) {
        if (CollectionUtils.isEmpty(list)) {
            throw new ServiceException("导入数据为空！");
        }

        int successCount = 0;
        StringBuilder errorMsg = new StringBuilder();

        for (int i = 0; i < list.size(); i++) {
            EmploymentApproval employmentApproval = list.get(i);
            try {
                // 2. 检查是否重复（可选）
                if (employmentApprovalMapper.checkExists(employmentApproval)) {
                    throw new ServiceException("第" + (i + 1) + "行数据已存在");
                }

                // 3. 插入数据库
                employmentApprovalMapper.insertEmploymentApproval(employmentApproval);
                successCount++;
            } catch (Exception e) {
                errorMsg.append("<br/>第").append(i + 1).append("行错误：").append(e.getMessage());
            }
        }

        return String.format("成功导入 %d 条数据，失败 %d 条：%s",
                successCount, list.size() - successCount, errorMsg);
    }


    /**
     * 查询入职草稿箱列表
     *
     */
    @Override
    public List<EmploymentApproval> selectEmploymentApprovalDraftList(EmploymentApproval employmentApproval)
    {
        return employmentApprovalMapper.selectEmploymentApprovalDraftList(employmentApproval);
    }

    @Override
    public int insertEmploymentApprovalDraft(EmploymentApproval employmentApproval)
    {
        return employmentApprovalMapper.insertEmploymentApprovalDraft(employmentApproval);
    }

    @Override
    public int updateEmploymentApprovalDraft(EmploymentApproval employmentApproval)
    {
        employmentApproval.setUpdateTime(DateUtils.getNowDate());
        employmentApproval.setIsDraft(1);
        return employmentApprovalMapper.updateEmploymentApprovalDraft(employmentApproval);
    }

    @Override
    public int updateApproval(EmploymentApproval employmentApproval)
    {
        employmentApproval.setUpdateTime(DateUtils.getNowDate());
        return employmentApprovalMapper.updateApproval(employmentApproval);
    }

    @Override
    public int updateApproval2(EmploymentApproval employmentApproval)
    {
        employmentApproval.setUpdateTime(DateUtils.getNowDate());
        return employmentApprovalMapper.updateApproval2(employmentApproval);
    }

    @Override
    public EmploymentApprovalDTO getCurrentUserApproval() {
        // 获取当前登录用户
        LoginUser loginUser = SecurityUtils.getLoginUser();
        if (loginUser == null) {
            throw new ServiceException("未登录");
        }
        System.out.println("loginUser = " + loginUser.getUserId());
        return employmentApprovalMapper.selectApprovalWithUser(loginUser.getUserId());
    }

    @Override
    public Long countTodayBirthday() {
        return employmentApprovalMapper.countTodayBirthday();
    }
    @Override
    public Long countCurrentQuarterBirthday() {
        return employmentApprovalMapper.countCurrentQuarterBirthday();
    }

}
