package com.ruoyi.mapper;

import java.util.List;
import com.ruoyi.domain.LeaveApplication;
import com.ruoyi.domain.dto.BatchUpdateDTO;
import com.ruoyi.domain.dto.EmployeeBalanceDTO;
import io.lettuce.core.dynamic.annotation.Param;
import java.util.Map;

/**
 * 请假申请Mapper接口
 * 
 * @author hht
 * @date 2025-03-03
 */
public interface LeaveApplicationMapper 
{
    /**
     * 查询请假申请
     * 
     * @param id 请假申请主键
     * @return 请假申请
     */
    public LeaveApplication selectLeaveApplicationById(Long id);

    /**
     * 查询请假申请列表
     * 
     * @param leaveApplication 请假申请
     * @return 请假申请集合
     */
    public List<LeaveApplication> selectLeaveApplicationList(LeaveApplication leaveApplication);

    /**
     * 新增请假申请
     * 
     * @param leaveApplication 请假申请
     * @return 结果
     */
    public int insertLeaveApplication(LeaveApplication leaveApplication);

    /**
     * 修改请假申请
     * 
     * @param leaveApplication 请假申请
     * @return 结果
     */
    public int updateLeaveApplication(LeaveApplication leaveApplication);

    /**
     * 删除请假申请
     * 
     * @param id 请假申请主键
     * @return 结果
     */
    public int deleteLeaveApplicationById(Long id);

    /**
     * 批量删除请假申请
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteLeaveApplicationByIds(Long[] ids);

    /**
     * 根据用户id查询请假总时长
     * @param userId
     * @return
     */
    EmployeeBalanceDTO selectDeductionOvertimeHoursByUserId(@Param("userId") Long userId);


        /**
         * 更新员工的加班总时长
         * @param dto 包含overtimeHoursBalance和employeeId的对象
         * @return 更新结果
         */
        int updateOvertimeHoursBalance(EmployeeBalanceDTO dto);

        /**
         * 查询项目经理
         * @return
         */
    List<String> selectProjectManagers();

    /**
     * 获取总经理的nick_name
     * @return 总经理的nick_name
     */
    String selectGeneralManagerNickName();


    /**
     * 根据节点id和审批状态更新请假申请
     * @param dto 包含节点id和审批状态的对象
     */
    int batchUpdateNodeIdAndApprovalStatus(BatchUpdateDTO dto);

}
