package com.ruoyi.material.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.ruoyi.attendance.enums.AttendanceDelFlag;
import com.ruoyi.attendance.enums.AttendanceDraft;
import com.ruoyi.material.domain.PsaMaterialType;
import com.ruoyi.material.domain.PsaMaterialTypeDetail;
import com.ruoyi.material.domain.dto.EditMaterialDTO;
import com.ruoyi.material.domain.dto.MaterialQueryDTO;
import com.ruoyi.material.domain.dto.PsaMaterialNewDTO;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.material.domain.PsaMaterial;
import com.ruoyi.material.service.IPsaMaterialService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 物品信息Controller
 * 
 * @author ruoyi
 * @date 2025-03-12
 */
@RestController
@RequestMapping("/psa/material")
public class PsaMaterialController extends BaseController
{
    @Autowired
    private IPsaMaterialService psaMaterialService;

    /**
     * 查询物品信息列表
     */
    @PreAuthorize("@ss.hasPermi('psa:material:list')")
    @GetMapping("/list")
    public TableDataInfo list(MaterialQueryDTO materialQueryDTO)
    {

        materialQueryDTO.setDraft(AttendanceDraft.NO.getValue());
        materialQueryDTO.setDelFlag(AttendanceDelFlag.EXIST.getValue());
        MaterialQueryDTO temp = psaMaterialService.temp(materialQueryDTO);
        startPage();
        List<PsaMaterial> list = psaMaterialService.selectPsaMaterialList(temp);
        return getDataTable(list);
    }

    /**
     * 查询草稿箱列表
     */
    @PreAuthorize("@ss.hasPermi('psa:material:list')")
    @GetMapping("/list/draft")
    public TableDataInfo listDraft(MaterialQueryDTO materialQueryDTO)
    {
        MaterialQueryDTO m = psaMaterialService.temp(materialQueryDTO);
        startPage();
        materialQueryDTO.setDraft(AttendanceDraft.YES.getValue());
        List<PsaMaterial> list = psaMaterialService.selectPsaMaterialList(m);
        return getDataTable(list);
    }

    /**
     * 导出物品信息列表
     */
    @PreAuthorize("@ss.hasPermi('psa:material:export')")
    @Log(title = "物品信息", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, PsaMaterial psaMaterial)
    {
        List<PsaMaterial> list = psaMaterialService.selectPsaMaterialList(psaMaterial);
        ExcelUtil<PsaMaterial> util = new ExcelUtil<PsaMaterial>(PsaMaterial.class);
        util.exportExcel(response, list, "物品信息数据","基础物品信息");
    }

    /**
     * 获取物品信息详细信息
     */
    @PreAuthorize("@ss.hasPermi('psa:material:query')")
    @GetMapping(value = "/{materialId}")
    public AjaxResult getInfo(@PathVariable("materialId") Long materialId)
    {
        return success(psaMaterialService.selectPsaMaterialByMaterialId(materialId));
    }

    /**
     * 新增物品信息
     */
    @PreAuthorize("@ss.hasPermi('psa:material:add')")
    @Log(title = "物品信息", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody PsaMaterialNewDTO psaMaterialNewDTO)
    {

        return toAjax(psaMaterialService.insertPsaMaterial(psaMaterialNewDTO));
    }

    /**
     * 修改物品信息
     */
    @PreAuthorize("@ss.hasPermi('psa:material:edit')")
    @Log(title = "物品信息", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody EditMaterialDTO editMaterialDTO)
    {
        return toAjax(psaMaterialService.updatePsaMaterial(editMaterialDTO));
    }

    /**
     * 删除物品信息
     */
    @PreAuthorize("@ss.hasPermi('psa:material:remove')")
    @Log(title = "物品信息", businessType = BusinessType.DELETE)
	@DeleteMapping("/{materialIds}")
    public AjaxResult remove(@PathVariable Long materialIds)
    {
        return toAjax(psaMaterialService.deletePsaMaterialByMaterialId(materialIds));
    }

    /**
     * 查询所有物品类别
     */
    @GetMapping("/type/list")
    public AjaxResult materialType()
    {
        List<PsaMaterialType> list = psaMaterialService.selectMaterialTypeList();
        return success(list);
    }
    /**
     * 查询所有类别的细分物品
     */
    @GetMapping("/type/detail/list")
    public AjaxResult materialTypeDetail()
    {
        List<PsaMaterialTypeDetail> list = psaMaterialService.selectMaterialTypeDetailList();
        return success(list);
    }

}
