package com.ruoyi.material.mapper;

import java.util.List;
import com.ruoyi.material.domain.PsaMaterial;
import com.ruoyi.material.domain.PsaMaterialType;
import com.ruoyi.material.domain.PsaMaterialTypeDetail;
import com.ruoyi.material.domain.dto.EditMaterialDTO;
import com.ruoyi.material.domain.dto.MaterialQueryDTO;
import com.ruoyi.material.domain.dto.PsaMaterialNewDTO;
import org.apache.ibatis.annotations.Mapper;
import org.apache.ibatis.annotations.Param;
import org.apache.ibatis.annotations.Select;
import org.apache.ibatis.annotations.Update;

/**
 * 物品信息Mapper接口
 * 
 * @author ruoyi
 * @date 2025-03-12
 */
@Mapper
public interface PsaMaterialMapper
{
    /**
     * 查询物品信息
     * 
     * @param materialId 物品信息主键
     * @return 物品信息
     */
    public PsaMaterial selectPsaMaterialByMaterialId(Long materialId);

    /**
     * 查询物品信息列表
     * 
     * @param psaMaterial 物品信息
     * @return 物品信息集合
     */
    public List<PsaMaterial> selectPsaMaterialList(PsaMaterial psaMaterial);

    /**
     * 新增物品信息
     * 
     * @param psaMaterial 物品信息
     * @return 结果
     */
    public int insertPsaMaterial(PsaMaterial psaMaterial);

    /**
     * 修改物品信息
     * 
     * @param psaMaterial 物品信息
     * @return 结果
     */
    public int updatePsaMaterial(PsaMaterial psaMaterial);



    /**
     * 删除物品信息
     * 
     * @param materialId 需要删除的数据主键集合
     * @return 结果
     */
    public int deletePsaMaterialByMaterialIds(Long materialId);
    /**
     * 查询所有物品类别
     */
    List<PsaMaterialType> selectPsaMaterialTypeList();
    /**
     * 查找该类别是否存在
     */
    int selectPsaMaterialTypeExist(Long id);
    /**
     * 新增物品类别
     */
    Long insertPsaMaterialType(PsaMaterialNewDTO psaMaterialNewDTO);
    /**
     * 新增类别下物品
     */
    Long insertPsaMaterialTypeDetail(PsaMaterialNewDTO psaMaterialNewDTO);
    /**
     * 查询所有类别的细分物品
     */
    List<PsaMaterialTypeDetail> selectPsaMaterialTypeDetailList();

    void updatePsaMaterialDetail(EditMaterialDTO editMaterialDTO);

    /**
     * 删除类型下细分物品
     */
    void deletePsaMaterialDetailById(Long itemId);

    /**
     * 物品名称模糊查
     */
    Long[] selectPsaMaterialTypeDetailIds(String itemId);

    List<PsaMaterial> selectPsaMaterialQueryList(MaterialQueryDTO materialQueryDTO);

    void addStock(@Param("materialId")Long materialId, @Param("entryQuantity")Long entryQuantity);

    void minusStock(@Param("materialId")Long materialId, @Param("minusQuantity")Long minusQuantity);

    Long getPsaMaterialId(@Param("materialTypeId")Long materialTypeId, @Param("materialTypeDetailId")Long materialTypeDetailId);
}
