package com.ruoyi.material.service.impl;

import cn.hutool.core.util.ArrayUtil;
import com.ruoyi.attendance.enums.AttendanceDelFlag;
import com.ruoyi.attendance.enums.AttendanceDraft;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.common.utils.SecurityUtils;
import com.ruoyi.material.domain.PsaMaterial;
import com.ruoyi.material.domain.PsaMaterialType;
import com.ruoyi.material.domain.PsaMaterialTypeDetail;
import com.ruoyi.material.domain.dto.EditMaterialDTO;
import com.ruoyi.material.domain.dto.MaterialQueryDTO;
import com.ruoyi.material.domain.dto.PsaMaterialNewDTO;
import com.ruoyi.material.mapper.PsaMaterialMapper;
import com.ruoyi.material.service.IPsaMaterialService;
import com.ruoyi.materialentry.domain.PsaMaterialEntry;
import com.ruoyi.materialentry.mapper.PsaMaterialEntryMapper;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;
import java.util.Random;

/**
 * 物品信息Service业务层处理
 * 
 * @author ruoyi
 * @date 2025-03-12
 */
@Service
public class PsaMaterialServiceImpl implements IPsaMaterialService 
{
    @Autowired
    private PsaMaterialMapper psaMaterialMapper;

    @Autowired
    private PsaMaterialEntryMapper psaMaterialEntryMapper;


    /**
     * 查询物品信息
     * 
     * @param materialId 物品信息主键
     * @return 物品信息
     */
    @Override
    public PsaMaterial selectPsaMaterialByMaterialId(Long materialId)
    {
        return psaMaterialMapper.selectPsaMaterialByMaterialId(materialId);
    }

    /**
     * 查询物品信息列表
     * 
     * @param materialQueryDTO 物品信息
     * @return 物品信息
     */
    @Override
    public List<PsaMaterial> selectPsaMaterialList(MaterialQueryDTO materialQueryDTO)
    {

        if (ArrayUtil.isEmpty(materialQueryDTO.getIds())){
            return new ArrayList<>();
        }
        return  psaMaterialMapper.selectPsaMaterialQueryList(materialQueryDTO);
    }

    @Override
    public List<PsaMaterial> selectPsaMaterialList(PsaMaterial psaMaterial)
    {
        return psaMaterialMapper.selectPsaMaterialList(psaMaterial);
    }

    /**
     * 新增物品信息
     * 
     * @param psaMaterialNewDTO 物品信息
     * @return 结果
     */
    @Override
    @Transactional
    public int insertPsaMaterial(PsaMaterialNewDTO psaMaterialNewDTO)
    {
        PsaMaterial psaMaterial = new PsaMaterial();
        if (psaMaterialMapper.selectPsaMaterialTypeExist(psaMaterialNewDTO.getTypeId())!=1){
            //没查到，是新增的类型
            psaMaterialMapper.insertPsaMaterialType(psaMaterialNewDTO);
            Long id =psaMaterialNewDTO.getId();
            //插入类别下物品
            psaMaterialNewDTO.setId(id);
            psaMaterialMapper.insertPsaMaterialTypeDetail(psaMaterialNewDTO);
            Long detailId = psaMaterialNewDTO.getId();
            psaMaterial.setTypeId(id);
            psaMaterial.setItemId(detailId);
        } else {
            psaMaterialMapper.insertPsaMaterialTypeDetail(psaMaterialNewDTO);
            Long detailId =psaMaterialNewDTO.getId();
            psaMaterial.setTypeId(psaMaterialNewDTO.getTypeId());
            psaMaterial.setItemId(detailId);
        }
        if (psaMaterialNewDTO.getStock()==null){
            psaMaterial.setStock(0L);
        }else {
            psaMaterial.setStock(psaMaterialNewDTO.getStock());
        }
        psaMaterial.setUnit(psaMaterialNewDTO.getUnit());
        psaMaterial.setItemCode(randomCodeGenerator());
        psaMaterial.setRemark(psaMaterialNewDTO.getRemark());
        psaMaterial.setCreateTime(DateUtils.getNowDate());
        psaMaterial.setCreateBy(SecurityUtils.getLoginUser().getUsername());
        if (psaMaterialNewDTO.getDraft().equals(AttendanceDraft.YES.getValue())){
            psaMaterial.setDraft(AttendanceDraft.YES.getValue());
        }else {
            psaMaterial.setDraft(AttendanceDraft.NO.getValue());
        }
        psaMaterial.setDelFlag(AttendanceDelFlag.EXIST.getValue());
        int i = psaMaterialMapper.insertPsaMaterial(psaMaterial);

        //库存有数据直接调盘点入库
        if(psaMaterialNewDTO.getStock()!=null && psaMaterialNewDTO.getStock()>0
                && psaMaterialNewDTO.getDraft().equals(AttendanceDraft.NO.getValue())){
            PsaMaterialEntry psaMaterialEntry = new PsaMaterialEntry();
            psaMaterialEntry.setEntryMethod("1");
            psaMaterialEntry.setEntryQuantity(psaMaterialNewDTO.getStock());
            psaMaterialEntry.setTypeId(psaMaterial.getTypeId());
            psaMaterialEntry.setItemId(psaMaterial.getItemId());
            psaMaterialEntry.setItemName(psaMaterialEntryMapper.getMaterialDeatailName(psaMaterial.getItemId()));
            psaMaterialEntry.setMaterialId(psaMaterialEntryMapper.getMaterialId(psaMaterialEntry));
            psaMaterialEntry.setCreateTime(DateUtils.getNowDate());
            psaMaterialEntry.setCreateBy(SecurityUtils.getUsername());
            psaMaterialEntry.setRemark(psaMaterialNewDTO.getRemark());
            psaMaterialEntryMapper.insertPsaMaterialEntry(psaMaterialEntry);
        }
        return i;
    }
    /**
     * 修改物品信息
     * 
     * @param editMaterialDTO 物品信息
     * @return 结果
     */
    @Override
    public int updatePsaMaterial(EditMaterialDTO editMaterialDTO)
    {
        psaMaterialMapper.updatePsaMaterialDetail(editMaterialDTO);
        if (editMaterialDTO.getDraft().equals(AttendanceDraft.YES.getValue())){
            editMaterialDTO.setDraft(AttendanceDraft.NO.getValue());
            if (editMaterialDTO.getStock()>0){
                PsaMaterialEntry psaMaterialEntry = new PsaMaterialEntry();
                psaMaterialEntry.setEntryMethod("1");
                psaMaterialEntry.setEntryQuantity(editMaterialDTO.getStock());
                psaMaterialEntry.setTypeId(editMaterialDTO.getTypeId());
                psaMaterialEntry.setItemId(editMaterialDTO.getItemId());
                psaMaterialEntry.setItemName(psaMaterialEntryMapper.getMaterialDeatailName(editMaterialDTO.getItemId()));
                psaMaterialEntry.setMaterialId(psaMaterialEntryMapper.getMaterialId(psaMaterialEntry));
                psaMaterialEntry.setCreateTime(DateUtils.getNowDate());
                psaMaterialEntry.setCreateBy(SecurityUtils.getUsername());
                psaMaterialEntry.setRemark(editMaterialDTO.getRemark());
                psaMaterialEntryMapper.insertPsaMaterialEntry(psaMaterialEntry);
            }
        }
        PsaMaterial psaMaterial = new PsaMaterial();
        psaMaterial.setTypeId(editMaterialDTO.getTypeId());
        psaMaterial.setStock(editMaterialDTO.getStock());
        psaMaterial.setUnit(editMaterialDTO.getUnit());
        psaMaterial.setRemark(editMaterialDTO.getRemark());
        psaMaterial.setMaterialId(editMaterialDTO.getMaterialId());
        psaMaterial.setDraft(editMaterialDTO.getDraft());
        psaMaterial.setUpdateTime(DateUtils.getNowDate());

        return psaMaterialMapper.updatePsaMaterial(psaMaterial);
    }

    /**
     * 删除物品信息
     * @return 结果
     */
    @Override
    @Transactional
    public int deletePsaMaterialByMaterialId(Long materialId)
    {
        PsaMaterial psaMaterial = psaMaterialMapper.selectPsaMaterialByMaterialId(materialId);
                psaMaterialMapper.deletePsaMaterialDetailById(psaMaterial.getItemId());
        return  psaMaterialMapper.deletePsaMaterialByMaterialIds(materialId);
    }

    /**
     * 查询所有物品类别
     */
    @Override
    public List<PsaMaterialType> selectMaterialTypeList() {
        return psaMaterialMapper.selectPsaMaterialTypeList();
    }
    /**
     * 查询所有类别的细分物品
     */
    @Override
    public List<PsaMaterialTypeDetail> selectMaterialTypeDetailList() {
        return  psaMaterialMapper.selectPsaMaterialTypeDetailList();
    }

    @Override
    public MaterialQueryDTO temp(MaterialQueryDTO materialQueryDTO) {
        Long[] ids = psaMaterialMapper.selectPsaMaterialTypeDetailIds(materialQueryDTO.getItemId());
        materialQueryDTO.setIds(ids);
        return materialQueryDTO;
    }

    public String randomCodeGenerator(){
        // 获取当前时间，并格式化为"YYYYMMDDHHMMSS"形式
        SimpleDateFormat sdf = new SimpleDateFormat("yyyyMMddHHmmss");
        String currentTime = sdf.format(new Date());
        // 生成两个随机的大写字母
        Random random = new Random();
        char[] letters = new char[2];
        for (int i = 0; i < 2; i++) {
            letters[i] = (char) ('A' + random.nextInt(26));
        }
        return new String(letters) + currentTime;
    }
}
