package com.ruoyi.materialapply.controller;
import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.ruoyi.materialapply.domain.ProjectUser;
import com.ruoyi.materialapply.domain.PsaMaterialApply;
import com.ruoyi.materialapply.service.IPsaMaterialApplyService;
import com.ruoyi.materialreturn.domain.PsaMaterialReturn;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;
/**
 * 物品借用申请Controller
 * 
 * @author ruoyi
 * @date 2025-03-18
 */
@RestController
@RequestMapping("/material/apply")
public class PsaMaterialApplyController extends BaseController
{
    @Autowired
    private IPsaMaterialApplyService psaMaterialApplyService;

    /**
     * 查询物品借用申请列表
     */
    @PreAuthorize("@ss.hasPermi('material:apply:list')")
    @GetMapping("/list")
    public TableDataInfo list(PsaMaterialApply psaMaterialApply)
    {
        startPage();
        List<PsaMaterialApply> list = psaMaterialApplyService.selectPsaMaterialApplyList(psaMaterialApply);
        return getDataTable(list);
    }

    /**
     * 导出物品借用申请列表
     */
    @PreAuthorize("@ss.hasPermi('material:apply:export')")
    @Log(title = "物品借用申请", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, PsaMaterialApply psaMaterialApply)
    {
        List<PsaMaterialApply> list = psaMaterialApplyService.selectPsaMaterialApplyList(psaMaterialApply);
        ExcelUtil<PsaMaterialApply> util = new ExcelUtil<PsaMaterialApply>(PsaMaterialApply.class);
        util.exportExcel(response, list, "物品借用申请数据","物品借用记录");
    }

    /**
     * 获取物品借用申请详细信息
     */
    @PreAuthorize("@ss.hasPermi('material:apply:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(psaMaterialApplyService.selectPsaMaterialApplyById(id));
    }

    /**
     * 新增物品借用申请
     */
    @PreAuthorize("@ss.hasPermi('material:apply:add')")
    @Log(title = "物品借用申请", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody PsaMaterialApply psaMaterialApply)
    {
        return toAjax(psaMaterialApplyService.insertPsaMaterialApply(psaMaterialApply));
    }

    /**
     * 修改物品借用申请
     */
    @PreAuthorize("@ss.hasPermi('material:apply:edit')")
    @Log(title = "物品借用申请", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody PsaMaterialApply psaMaterialApply)
    {
        return toAjax(psaMaterialApplyService.updatePsaMaterialApply(psaMaterialApply));
    }

    /**
     * 审核借用申请
     */
    @PreAuthorize("@ss.hasPermi('material:apply:check')")
    @Log(title = "物品归还审核", businessType = BusinessType.UPDATE)
    @PutMapping("/check")
    public AjaxResult check(@RequestBody PsaMaterialApply psaMaterialApply)
    {
        return toAjax(psaMaterialApplyService.checkPsaMaterialReturn(psaMaterialApply));
    }

    /**
     * 删除物品借用申请
     */
    @PreAuthorize("@ss.hasPermi('material:apply:remove')")
    @Log(title = "物品借用申请", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(psaMaterialApplyService.deletePsaMaterialApplyByIds(ids));
    }
    /**
     * 查项目和用户中间表
     */
    @GetMapping("/selectuser")
    public AjaxResult select()
    {
        List<ProjectUser> p = psaMaterialApplyService.selectPorjectUser();
        return success(p);
    }
}
