package com.ruoyi.materialapply.service.impl;

import java.util.List;

import cn.hutool.core.util.StrUtil;
import com.ruoyi.attendance.enums.AttendanceDelFlag;
import com.ruoyi.attendance.enums.AttendanceDraft;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.common.utils.SecurityUtils;
import com.ruoyi.material.mapper.PsaMaterialMapper;
import com.ruoyi.materialapply.domain.ProjectUser;
import com.ruoyi.materialapply.domain.PsaMaterialApply;
import com.ruoyi.materialapply.domain.PsaMaterialApplyDetail;

import com.ruoyi.materialapply.enums.MaterialApplyStatus;
import com.ruoyi.materialapply.mapper.PsaMaterialApplyMapper;
import com.ruoyi.materialapply.service.IPsaMaterialApplyService;
import com.ruoyi.materialreturn.domain.PsaMaterialReturnDetail;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import java.util.ArrayList;
import com.ruoyi.common.utils.StringUtils;
import org.springframework.transaction.annotation.Transactional;


/**
 * 物品借用申请Service业务层处理
 * 
 * @author ruoyi
 * @date 2025-03-18
 */
@Service
public class PsaMaterialApplyServiceImpl implements IPsaMaterialApplyService
{
    @Autowired
    private PsaMaterialApplyMapper psaMaterialApplyMapper;

    @Autowired
    private PsaMaterialMapper psaMaterialMapper;

    /**
     * 查询物品借用申请
     * 
     * @param id 物品借用申请主键
     * @return 物品借用申请
     */
    @Override
    public PsaMaterialApply selectPsaMaterialApplyById(Long id)
    {
        return psaMaterialApplyMapper.selectPsaMaterialApplyById(id);
    }

    /**
     * 查询物品借用申请列表
     * 
     * @param psaMaterialApply 物品借用申请
     * @return 物品借用申请
     */
    @Override
    public List<PsaMaterialApply> selectPsaMaterialApplyList(PsaMaterialApply psaMaterialApply)
    {
        if (StrUtil.isBlank(psaMaterialApply.getDraft())){
            psaMaterialApply.setDraft(AttendanceDraft.NO.getValue());
        }else {
            psaMaterialApply.setUserId(SecurityUtils.getLoginUser().getUserId());
        }
        psaMaterialApply.setDelFlag(AttendanceDelFlag.EXIST.getValue());
        return psaMaterialApplyMapper.selectPsaMaterialApplyList(psaMaterialApply);
    }

    /**
     * 新增物品借用申请
     * 
     * @param psaMaterialApply 物品借用申请
     * @return 结果
     */
    @Transactional
    @Override
    public int insertPsaMaterialApply(PsaMaterialApply psaMaterialApply)
    {
        psaMaterialApply.setCheckStatus(MaterialApplyStatus.DSH.getValue());
        psaMaterialApply.setCreateBy(SecurityUtils.getUsername());
        psaMaterialApply.setCreateTime(DateUtils.getNowDate());
        if (StrUtil.isBlank(psaMaterialApply.getDraft())){
            psaMaterialApply.setDraft(AttendanceDraft.NO.getValue());
        }
        psaMaterialApply.setDelFlag(AttendanceDelFlag.EXIST.getValue());
        int rows = psaMaterialApplyMapper.insertPsaMaterialApply(psaMaterialApply);
        insertPsaMaterialApplyDetail(psaMaterialApply);
        return rows;
    }

    /**
     * 修改物品借用申请
     * 
     * @param psaMaterialApply 物品借用申请
     * @return 结果
     */
    @Transactional
    @Override
    public int updatePsaMaterialApply(PsaMaterialApply psaMaterialApply)
    {
        psaMaterialApply.setUpdateTime(DateUtils.getNowDate());
        psaMaterialApplyMapper.deletePsaMaterialApplyDetailByApplyId(psaMaterialApply.getId());
        insertPsaMaterialApplyDetail(psaMaterialApply);
        return psaMaterialApplyMapper.updatePsaMaterialApply(psaMaterialApply);
    }

    @Override
    public int checkPsaMaterialReturn(PsaMaterialApply psaMaterialApply) {
        psaMaterialApply.setApprovalDate(DateUtils.getNowDate());
        if (psaMaterialApply.getCheckStatus().equals(MaterialApplyStatus.TG.getValue())){
            List<PsaMaterialApplyDetail> psaMaterialApplyDetailList = psaMaterialApply.getPsaMaterialApplyDetailList();
            for (PsaMaterialApplyDetail detail : psaMaterialApplyDetailList) {
                // 获取物料ID
                Long id = psaMaterialMapper.getPsaMaterialId(
                        detail.getMaterialTypeId(),
                        detail.getMaterialTypeDetailId()
                );
                // 扣除库存
                psaMaterialMapper.minusStock(id, detail.getApplyNumber());
            }
        }
        return psaMaterialApplyMapper.updatePsaMaterialApply(psaMaterialApply);
    }



    /**
     * 批量删除物品借用申请
     * 
     * @param ids 需要删除的物品借用申请主键
     * @return 结果
     */
    @Transactional
    @Override
    public int deletePsaMaterialApplyByIds(Long[] ids)
    {
        psaMaterialApplyMapper.deletePsaMaterialApplyDetailByApplyIds(ids);
        return psaMaterialApplyMapper.deletePsaMaterialApplyByIds(ids);
    }

    /**
     * 删除物品借用申请信息
     * 
     * @param id 物品借用申请主键
     * @return 结果
     */
    @Transactional
    @Override
    public int deletePsaMaterialApplyById(Long id)
    {
        psaMaterialApplyMapper.deletePsaMaterialApplyDetailByApplyId(id);
        return psaMaterialApplyMapper.deletePsaMaterialApplyById(id);
    }

    @Override
    public List<ProjectUser> selectPorjectUser() {
        return psaMaterialApplyMapper.selectProjectUser();
    }

    /**
     * 新增物品借用细节信息
     * 
     * @param psaMaterialApply 物品借用申请对象
     */
    public void insertPsaMaterialApplyDetail(PsaMaterialApply psaMaterialApply)
    {
        List<PsaMaterialApplyDetail> psaMaterialApplyDetailList = psaMaterialApply.getPsaMaterialApplyDetailList();
        Long id = psaMaterialApply.getId();
        if (StringUtils.isNotNull(psaMaterialApplyDetailList))
        {
            List<PsaMaterialApplyDetail> list = new ArrayList<PsaMaterialApplyDetail>();
            for (PsaMaterialApplyDetail psaMaterialApplyDetail : psaMaterialApplyDetailList)
            {
                psaMaterialApplyDetail.setApplyId(id);
                list.add(psaMaterialApplyDetail);
            }
            if (list.size() > 0)
            {
                psaMaterialApplyMapper.batchPsaMaterialApplyDetail(list);
            }
        }
    }
}
