package com.ruoyi.materialentry.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.ruoyi.attendance.enums.AttendanceDraft;
import com.ruoyi.materialentry.domain.PsaMaterialEntry;
import com.ruoyi.materialentry.service.IPsaMaterialEntryService;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;

import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 物品入库信息Controller
 * 
 * @author ruoyi
 * @date 2025-03-13
 */
@RestController
@RequestMapping("/psa/entry")
public class PsaMaterialEntryController extends BaseController
{
    @Autowired
    private IPsaMaterialEntryService psaMaterialEntryService;

    /**
     * 查询物品入库信息列表
     */
    @PreAuthorize("@ss.hasPermi('psa:entry:list')")
    @GetMapping("/list")
    public TableDataInfo list(PsaMaterialEntry psaMaterialEntry)
    {
        startPage();
        List<PsaMaterialEntry> list = psaMaterialEntryService.selectPsaMaterialEntryList(psaMaterialEntry);
        return getDataTable(list);
    }

    /**
     * 查询物品草稿箱列表
     */
    @PreAuthorize("@ss.hasPermi('psa:entry:draft')")
    @GetMapping("/list/draft")
    public TableDataInfo listDraft(PsaMaterialEntry psaMaterialEntry)
    {
        startPage();
        List<PsaMaterialEntry> list = psaMaterialEntryService.selectPsaMaterialEntryDraftList(psaMaterialEntry);
        return getDataTable(list);
    }

    /**
     * 导出物品入库信息列表
     */
    @PreAuthorize("@ss.hasPermi('psa:entry:export')")
    @Log(title = "物品入库信息", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, PsaMaterialEntry psaMaterialEntry)
    {
        List<PsaMaterialEntry> list = psaMaterialEntryService.selectPsaMaterialEntryList(psaMaterialEntry);
        ExcelUtil<PsaMaterialEntry> util = new ExcelUtil<PsaMaterialEntry>(PsaMaterialEntry.class);
        util.exportExcel(response, list, "物品入库信息数据","物品入库记录");
    }

    /**
     * 获取物品入库信息详细信息
     */
    @PreAuthorize("@ss.hasPermi('psa:entry:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(psaMaterialEntryService.selectPsaMaterialEntryById(id));
    }

    /**
     * 新增物品入库信息
     */
    @PreAuthorize("@ss.hasPermi('psa:entry:add')")
    @Log(title = "物品入库信息", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody PsaMaterialEntry psaMaterialEntry)
    {
        return toAjax(psaMaterialEntryService.insertPsaMaterialEntry(psaMaterialEntry));
    }
    /**
     * 新增物品入库草稿
     */
    @PreAuthorize("@ss.hasPermi('psa:entry:draft')")
    @Log(title = "物品入库信息", businessType = BusinessType.INSERT)
    @PostMapping("/draft")
    public AjaxResult addDraft(@RequestBody PsaMaterialEntry psaMaterialEntry)
    {
        psaMaterialEntry.setDraft(AttendanceDraft.YES.getValue());
        return toAjax(psaMaterialEntryService.insertPsaMaterialEntry(psaMaterialEntry));
    }
    /**
     * 提交草稿
     */
    @PreAuthorize("@ss.hasPermi('psa:entry:drafttoadd')")
    @Log(title = "物品入库信息", businessType = BusinessType.INSERT)
    @PostMapping("/add/draft")
    public AjaxResult draftToAdd(@RequestBody PsaMaterialEntry psaMaterialEntry)
    {
        return toAjax(psaMaterialEntryService.addDraftPsaMaterialEntry(psaMaterialEntry));
    }
    /**
     * 修改物品入库信息
     */
    @PreAuthorize("@ss.hasPermi('psa:entry:edit')")
    @Log(title = "物品入库信息", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody PsaMaterialEntry psaMaterialEntry)
    {
        return toAjax(psaMaterialEntryService.updatePsaMaterialEntry(psaMaterialEntry));
    }

    /**
     * 删除物品入库信息
     */
    @PreAuthorize("@ss.hasPermi('psa:entry:remove')")
    @Log(title = "物品入库信息", businessType = BusinessType.DELETE)
	@DeleteMapping("/{id}")
    public AjaxResult remove(@PathVariable Long id)
    {
        return toAjax(psaMaterialEntryService.deletePsaMaterialEntryById(id));
    }
}
