package com.ruoyi.materialentry.service.impl;

import java.util.List;

import com.ruoyi.attendance.enums.AttendanceDelFlag;
import com.ruoyi.attendance.enums.AttendanceDraft;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.common.utils.SecurityUtils;
import com.ruoyi.material.domain.PsaMaterial;
import com.ruoyi.material.mapper.PsaMaterialMapper;
import com.ruoyi.materialentry.domain.PsaMaterialEntry;
import com.ruoyi.materialentry.mapper.PsaMaterialEntryMapper;
import com.ruoyi.materialentry.service.IPsaMaterialEntryService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;


/**
 * 物品入库信息Service业务层处理
 * 
 * @author ruoyi
 * @date 2025-03-13
 */
@Service
public class PsaMaterialEntryServiceImpl implements IPsaMaterialEntryService
{
    @Autowired
    private PsaMaterialEntryMapper psaMaterialEntryMapper;

    @Autowired
    private PsaMaterialMapper psaMaterialMapper;

    /**
     * 查询物品入库信息
     * 
     * @param id 物品入库信息主键
     * @return 物品入库信息
     */
    @Override
    public PsaMaterialEntry selectPsaMaterialEntryById(Long id)
    {
        return psaMaterialEntryMapper.selectPsaMaterialEntryById(id);
    }

    /**
     * 查询物品入库信息列表
     * 
     * @param psaMaterialEntry 物品入库信息
     * @return 物品入库信息
     */
    @Override
    public List<PsaMaterialEntry> selectPsaMaterialEntryList(PsaMaterialEntry psaMaterialEntry)
    {
        psaMaterialEntry.setDraft(AttendanceDraft.NO.getValue());
        psaMaterialEntry.setDelFlag(AttendanceDelFlag.EXIST.getValue());
        return psaMaterialEntryMapper.selectPsaMaterialEntryList(psaMaterialEntry);
    }
    /**
     * 查询物品入库草稿箱列表
     *
     * @param psaMaterialEntry 物品入库信息
     * @return 物品入库信息
     */
    @Override
    public List<PsaMaterialEntry> selectPsaMaterialEntryDraftList(PsaMaterialEntry psaMaterialEntry) {
        psaMaterialEntry.setDraft(AttendanceDraft.YES.getValue());
        return psaMaterialEntryMapper.selectPsaMaterialEntryList(psaMaterialEntry);
    }

    /**
     * 新增物品入库信息
     * 
     * @param psaMaterialEntry 物品入库信息
     * @return 结果
     */
    @Override
    public int insertPsaMaterialEntry(PsaMaterialEntry psaMaterialEntry)
    {
        psaMaterialEntry.setMaterialId(psaMaterialEntryMapper.getMaterialId(psaMaterialEntry));
        psaMaterialEntry.setItemName(psaMaterialEntryMapper.getMaterialDeatailName(psaMaterialEntry.getItemId()));
        psaMaterialEntry.setCreateTime(DateUtils.getNowDate());
        psaMaterialEntry.setCreateBy(SecurityUtils.getUsername());
        if (psaMaterialEntry.getDraft() == null){
            psaMaterialMapper.addStock(psaMaterialEntry.getMaterialId(),psaMaterialEntry.getEntryQuantity());
        }
//        SecurityUtils.getLoginUser().getUsername()
        return psaMaterialEntryMapper.insertPsaMaterialEntry(psaMaterialEntry);
    }

    /**
     * 修改物品入库信息
     * 
     * @param psaMaterialEntry 物品入库信息
     * @return 结果
     */
    @Override
    public int updatePsaMaterialEntry(PsaMaterialEntry psaMaterialEntry)
    {
        psaMaterialEntry.setUpdateTime(DateUtils.getNowDate());
        return psaMaterialEntryMapper.updatePsaMaterialEntry(psaMaterialEntry);
    }

    /**
     * 批量删除物品入库信息
     * 
     * @param ids 需要删除的物品入库信息主键
     * @return 结果
     */
    @Override
    public int deletePsaMaterialEntryByIds(Long[] ids)
    {
        return psaMaterialEntryMapper.deletePsaMaterialEntryByIds(ids);
    }

    /**
     * 删除物品入库信息信息
     * 
     * @param id 物品入库信息主键
     * @return 结果
     */
    @Override
    public int deletePsaMaterialEntryById(Long id)
    {
        PsaMaterialEntry psaMaterialEntry = psaMaterialEntryMapper.selectPsaMaterialEntryById(id);
        if (psaMaterialEntry.getDraft().equals(AttendanceDraft.YES.getValue())){
            return psaMaterialEntryMapper.deletePsaMaterialEntryById(id);
        }
        PsaMaterial psaMaterial = psaMaterialMapper.selectPsaMaterialByMaterialId(psaMaterialEntry.getMaterialId());
        if (psaMaterial.getStock()<psaMaterialEntry.getEntryQuantity()) {
            return 0;
        }
        psaMaterialMapper.minusStock(psaMaterialEntry.getMaterialId(),psaMaterialEntry.getEntryQuantity());
        psaMaterialEntry.setDelFlag(AttendanceDelFlag.DELETE.getValue());
        return psaMaterialEntryMapper.updatePsaMaterialEntry(psaMaterialEntry);
    }

    @Override
    public int addDraftPsaMaterialEntry(PsaMaterialEntry psaMaterialEntry) {
        deletePsaMaterialEntryById(psaMaterialEntry.getId());
        psaMaterialEntry.setDraft(null);
        return insertPsaMaterialEntry(psaMaterialEntry);
    }
}
