package com.ruoyi.materialreturn.service.impl;

import java.util.List;

import cn.hutool.core.util.StrUtil;
import com.ruoyi.attendance.enums.AttendanceDelFlag;
import com.ruoyi.attendance.enums.AttendanceDraft;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.common.utils.SecurityUtils;
import com.ruoyi.material.mapper.PsaMaterialMapper;
import com.ruoyi.materialapply.enums.MaterialApplyStatus;
import com.ruoyi.materialreturn.domain.PsaMaterialReturn;
import com.ruoyi.materialreturn.domain.PsaMaterialReturnDetail;
import com.ruoyi.materialreturn.mapper.PsaMaterialReturnMapper;
import com.ruoyi.materialreturn.service.IPsaMaterialReturnService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import java.util.ArrayList;
import com.ruoyi.common.utils.StringUtils;
import org.springframework.transaction.annotation.Transactional;


/**
 * 物品归还申请Service业务层处理
 * 
 * @author fangjianyu
 * @date 2025-03-25
 */
@Service
public class PsaMaterialReturnServiceImpl implements IPsaMaterialReturnService
{
    @Autowired
    private PsaMaterialReturnMapper psaMaterialReturnMapper;
    @Autowired
    private PsaMaterialMapper psaMaterialMapper;

    /**
     * 查询物品归还申请
     * 
     * @param id 物品归还申请主键
     * @return 物品归还申请
     */
    @Override
    public PsaMaterialReturn selectPsaMaterialReturnById(Long id)
    {
        return psaMaterialReturnMapper.selectPsaMaterialReturnById(id);
    }

    /**
     * 查询物品归还申请列表
     * 
     * @param psaMaterialReturn 物品归还申请
     * @return 物品归还申请
     */
    @Override
    public List<PsaMaterialReturn> selectPsaMaterialReturnList(PsaMaterialReturn psaMaterialReturn)
    {
        if (StrUtil.isBlank(psaMaterialReturn.getDraft())){
            psaMaterialReturn.setDraft(AttendanceDraft.NO.getValue());
        }
        psaMaterialReturn.setDelFlag(AttendanceDelFlag.EXIST.getValue());
        return psaMaterialReturnMapper.selectPsaMaterialReturnList(psaMaterialReturn);
    }

    /**
     * 新增物品归还申请
     * 
     * @param psaMaterialReturn 物品归还申请
     * @return 结果
     */
    @Transactional
    @Override
    public int insertPsaMaterialReturn(PsaMaterialReturn psaMaterialReturn)
    {
        psaMaterialReturn.setCreateBy(SecurityUtils.getUsername());
        psaMaterialReturn.setCheckStatus(MaterialApplyStatus.DSH.getValue());
        if (StrUtil.isBlank(psaMaterialReturn.getDraft())){
            psaMaterialReturn.setDraft(AttendanceDraft.NO.getValue());
        }
        psaMaterialReturn.setDelFlag(AttendanceDelFlag.EXIST.getValue());
        psaMaterialReturn.setCreateTime(DateUtils.getNowDate());
        int rows = psaMaterialReturnMapper.insertPsaMaterialReturn(psaMaterialReturn);
        insertPsaMaterialReturnDetail(psaMaterialReturn);
        return rows;
    }

    /**
     * 修改物品归还申请
     * 
     * @param psaMaterialReturn 物品归还申请
     * @return 结果
     */
    @Transactional
    @Override
    public int updatePsaMaterialReturn(PsaMaterialReturn psaMaterialReturn)
    {
        psaMaterialReturn.setUpdateTime(DateUtils.getNowDate());
        psaMaterialReturnMapper.deletePsaMaterialReturnDetailByReturnId(psaMaterialReturn.getId());
        insertPsaMaterialReturnDetail(psaMaterialReturn);
        return psaMaterialReturnMapper.updatePsaMaterialReturn(psaMaterialReturn);
    }
    /**
     * 审核物品归还
     *
     * @param psaMaterialReturn 物品归还申请
     * @return 结果
     */
    @Override
    public int checkPsaMaterialReturn(PsaMaterialReturn psaMaterialReturn) {
        psaMaterialReturn.setApprovalDate(DateUtils.getNowDate());
        if (psaMaterialReturn.getCheckStatus().equals(MaterialApplyStatus.TG.getValue())) {
            // 通过归还，加库存
            List<PsaMaterialReturnDetail> psaMaterialReturnDetailList = psaMaterialReturn.getPsaMaterialReturnDetailList();
            // 遍历物料归还明细列表
            for (PsaMaterialReturnDetail detail : psaMaterialReturnDetailList) {
                // 获取物料ID
                Long id = psaMaterialMapper.getPsaMaterialId(
                        detail.getMaterialTypeId(),
                        detail.getMaterialTypeDetailId()
                );
                // 增加库存
                psaMaterialMapper.addStock(id, detail.getReturnNumber());
            }
        }
        return psaMaterialReturnMapper.updatePsaMaterialReturn(psaMaterialReturn);
    }


    /**
     * 批量删除物品归还申请
     * 
     * @param ids 需要删除的物品归还申请主键
     * @return 结果
     */
    @Transactional
    @Override
    public int deletePsaMaterialReturnByIds(Long[] ids)
    {
        psaMaterialReturnMapper.deletePsaMaterialReturnDetailByReturnIds(ids);
        return psaMaterialReturnMapper.deletePsaMaterialReturnByIds(ids);
    }

    /**
     * 删除物品归还申请信息
     * 
     * @param id 物品归还申请主键
     * @return 结果
     */
    @Transactional
    @Override
    public int deletePsaMaterialReturnById(Long id)
    {
        psaMaterialReturnMapper.deletePsaMaterialReturnDetailByReturnId(id);
        return psaMaterialReturnMapper.deletePsaMaterialReturnById(id);
    }


    /**
     * 新增物品归还细节信息
     * 
     * @param psaMaterialReturn 物品归还申请对象
     */
    public void insertPsaMaterialReturnDetail(PsaMaterialReturn psaMaterialReturn)
    {
        List<PsaMaterialReturnDetail> psaMaterialReturnDetailList = psaMaterialReturn.getPsaMaterialReturnDetailList();
        Long id = psaMaterialReturn.getId();
        if (StringUtils.isNotNull(psaMaterialReturnDetailList))
        {
            List<PsaMaterialReturnDetail> list = new ArrayList<PsaMaterialReturnDetail>();
            for (PsaMaterialReturnDetail psaMaterialReturnDetail : psaMaterialReturnDetailList)
            {
                psaMaterialReturnDetail.setReturnId(id);
                list.add(psaMaterialReturnDetail);
            }
            if (list.size() > 0)
            {
                psaMaterialReturnMapper.batchPsaMaterialReturnDetail(list);
            }
        }
    }
}
