package com.ruoyi.regularization.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.regularization.domain.ApprovalRegularization;
import com.ruoyi.regularization.service.IApprovalRegularizationService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 转正审批Controller
 * 
 * @author ruoyi
 * @date 2025-02-26
 */
@RestController
@RequestMapping("/confirmationmanage/confirmationmanage")
public class ApprovalRegularizationController extends BaseController
{
    @Autowired
    private IApprovalRegularizationService approvalRegularizationService;

    /**
     * 查询转正审批列表
     */
    //@PreAuthorize("@ss.hasPermi('regularization:regularization:list')")
    @PreAuthorize("@ss.hasRole('admin') or @ss.hasRole('project-manager') or @ss.hasRole('hr') or @ss.hasRole('general-manager')")
    @GetMapping("/list")
    public TableDataInfo list(ApprovalRegularization approvalRegularization)
    {
        startPage();
        List<ApprovalRegularization> list = approvalRegularizationService.selectApprovalRegularizationList(approvalRegularization);
        return getDataTable(list);
    }

    /**
     * 导出转正审批列表
     */
    //@PreAuthorize("@ss.hasPermi('regularization:regularization:export')")
    @PreAuthorize("@ss.hasRole('admin') or @ss.hasRole('project-manager') or @ss.hasRole('hr') or @ss.hasRole('general-manager')")
    @Log(title = "转正审批", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, ApprovalRegularization approvalRegularization)
    {
        List<ApprovalRegularization> list = approvalRegularizationService.selectApprovalRegularizationList(approvalRegularization);
        ExcelUtil<ApprovalRegularization> util = new ExcelUtil<ApprovalRegularization>(ApprovalRegularization.class);
        util.exportExcel(response, list, "转正审批数据");
    }

    /**
     * 获取转正审批详细信息
     */
    //@PreAuthorize("@ss.hasPermi('regularization:regularization:query')")
    @PreAuthorize("@ss.hasRole('admin') or @ss.hasRole('project-manager') or @ss.hasRole('hr') or @ss.hasRole('general-manager')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(approvalRegularizationService.selectApprovalRegularizationById(id));
    }

    /**
     * 新增转正审批
     */
    //@PreAuthorize("@ss.hasPermi('regularization:regularization:add')")
    @PreAuthorize("@ss.hasRole('admin') or @ss.hasRole('project-manager') or @ss.hasRole('hr') or @ss.hasRole('general-manager') or @ss.hasRole('common')")
    @Log(title = "转正审批", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody ApprovalRegularization approvalRegularization)
    {
        return toAjax(approvalRegularizationService.insertApprovalRegularization(approvalRegularization));
    }

    /**
     * 修改转正审批
     */
    //@PreAuthorize("@ss.hasPermi('regularization:regularization:edit')")
    @PreAuthorize("@ss.hasRole('admin') or @ss.hasRole('project-manager') or @ss.hasRole('hr') or @ss.hasRole('general-manager')")
    @Log(title = "转正审批", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody ApprovalRegularization approvalRegularization)
    {
        return toAjax(approvalRegularizationService.updateApprovalRegularization(approvalRegularization));
    }

    /**
     * 删除转正审批
     */
    //@PreAuthorize("@ss.hasPermi('regularization:regularization:remove')")
    @PreAuthorize("@ss.hasRole('admin') or @ss.hasRole('project-manager') or @ss.hasRole('hr') or @ss.hasRole('general-manager')")
    @Log(title = "转正审批", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(approvalRegularizationService.deleteApprovalRegularizationByIds(ids));
    }



    @PreAuthorize("@ss.hasRole('admin') or @ss.hasRole('project-manager') or @ss.hasRole('hr') or @ss.hasRole('general-manager')")
    @Log(title = "转正审批", businessType = BusinessType.UPDATE)
    @PostMapping("/updateRegular")
    public AjaxResult updateRegular(@RequestBody ApprovalRegularization approvalRegularization)
    {
        return toAjax(approvalRegularizationService.updateRegular(approvalRegularization));
    }


    @PreAuthorize("@ss.hasRole('admin') or @ss.hasRole('project-manager') or @ss.hasRole('hr') or @ss.hasRole('general-manager')")
    @Log(title = "转正审批", businessType = BusinessType.UPDATE)
    @PostMapping("/updateRegular2")
    public AjaxResult updateRegular2(@RequestBody ApprovalRegularization approvalRegularization)
    {
        return toAjax(approvalRegularizationService.updateRegular2(approvalRegularization));
    }


    @PreAuthorize("@ss.hasRole('admin') or @ss.hasRole('project-manager') or @ss.hasRole('hr') or @ss.hasRole('general-manager')")
    @GetMapping("/getCountCurrentRegularizationInTenDays")
    public AjaxResult getCountCurrentRegularizationInTenDays()
    {
        return AjaxResult.success(approvalRegularizationService.countCurrentRegularizationInTenDays());
    }




}
