package com.ruoyi.resignation.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.resignation.domain.ResignationApplication;
import com.ruoyi.resignation.service.IResignationApplicationService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 离职申请Controller
 * 
 * @author ruoyi
 * @date 2025-02-26
 */
@RestController
@RequestMapping("/leavemanage/leavemanage")
public class ResignationApplicationController extends BaseController
{
    @Autowired
    private IResignationApplicationService resignationApplicationService;

    /**
     * 查询离职申请列表
     */
    //@PreAuthorize("@ss.hasPermi('resignation:resignation:list')")
    @PreAuthorize("@ss.hasRole('admin') or @ss.hasRole('project-manager') or @ss.hasRole('hr') or @ss.hasRole('general-manager') or @ss.hasRole('work-manage')")
    @GetMapping("/list")
    public TableDataInfo list(ResignationApplication resignationApplication)
    {
        startPage();
        List<ResignationApplication> list = resignationApplicationService.selectResignationApplicationList(resignationApplication);
        return getDataTable(list);
    }

    /**
     * 导出离职申请列表
     */
    //@PreAuthorize("@ss.hasPermi('resignation:resignation:export')")
    @PreAuthorize("@ss.hasRole('admin') or @ss.hasRole('project-manager') or @ss.hasRole('hr') or @ss.hasRole('general-manager')")
    @Log(title = "离职申请", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, ResignationApplication resignationApplication)
    {
        List<ResignationApplication> list = resignationApplicationService.selectResignationApplicationList(resignationApplication);
        ExcelUtil<ResignationApplication> util = new ExcelUtil<ResignationApplication>(ResignationApplication.class);
        util.exportExcel(response, list, "离职申请数据");
    }

    /**
     * 获取离职申请详细信息
     */
    //@PreAuthorize("@ss.hasPermi('resignation:resignation:query')")
    @PreAuthorize("@ss.hasRole('admin') or @ss.hasRole('project-manager') or @ss.hasRole('hr') or @ss.hasRole('general-manager')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(resignationApplicationService.selectResignationApplicationById(id));
    }

    /**
     * 新增离职申请
     */
    //@PreAuthorize("@ss.hasPermi('resignation:resignation:add')")
    @PreAuthorize("@ss.hasRole('admin') or @ss.hasRole('project-manager') or @ss.hasRole('hr') or @ss.hasRole('general-manager') or @ss.hasRole('common')")
    @Log(title = "离职申请", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody ResignationApplication resignationApplication)
    {
        return toAjax(resignationApplicationService.insertResignationApplication(resignationApplication));
    }

    /**
     * 修改离职申请
     */
    //@PreAuthorize("@ss.hasPermi('resignation:resignation:edit')")
    @PreAuthorize("@ss.hasRole('admin') or @ss.hasRole('project-manager') or @ss.hasRole('hr') or @ss.hasRole('general-manager')")
    @Log(title = "离职申请", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody ResignationApplication resignationApplication)
    {
        return toAjax(resignationApplicationService.updateResignationApplication(resignationApplication));
    }

    /**
     * 删除离职申请
     */
    //@PreAuthorize("@ss.hasPermi('resignation:resignation:remove')")
    @PreAuthorize("@ss.hasRole('admin') or @ss.hasRole('project-manager') or @ss.hasRole('hr') or @ss.hasRole('general-manager')")
    @Log(title = "离职申请", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(resignationApplicationService.deleteResignationApplicationByIds(ids));
    }


    @PreAuthorize("@ss.hasRole('admin') or @ss.hasRole('project-manager') or @ss.hasRole('hr') or @ss.hasRole('general-manager') or @ss.hasRole('work-manage')")
    @Log(title = "离职申请", businessType = BusinessType.UPDATE)
    @PostMapping("/updateResignation")
    public AjaxResult updateResignation(@RequestBody ResignationApplication resignationApplication)
    {
        return toAjax(resignationApplicationService.updateResignation(resignationApplication));
    }


    @PreAuthorize("@ss.hasRole('admin') or @ss.hasRole('project-manager') or @ss.hasRole('hr') or @ss.hasRole('general-manager') or @ss.hasRole('work-manage')")
    @Log(title = "离职申请", businessType = BusinessType.UPDATE)
    @PostMapping("/updateResignation2")
    public AjaxResult updateResignation2(@RequestBody ResignationApplication resignationApplication)
    {
        return toAjax(resignationApplicationService.updateResignation2(resignationApplication));
    }
}
