package com.ruoyi.resignation.service.impl;

import java.util.ArrayList;
import java.util.List;

import com.ruoyi.common.utils.StringUtils;
import com.ruoyi.resignation.domain.ResignationMatter;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.resignation.mapper.ResignationApplicationMapper;
import com.ruoyi.resignation.domain.ResignationApplication;
import com.ruoyi.resignation.service.IResignationApplicationService;
import org.springframework.transaction.annotation.Transactional;

/**
 * 离职申请Service业务层处理
 * 
 * @author ruoyi
 * @date 2025-02-26
 */
@Service
public class ResignationApplicationServiceImpl implements IResignationApplicationService 
{
    @Autowired
    private ResignationApplicationMapper resignationApplicationMapper;


    /**
     * 查询离职申请
     * 
     * @param id 离职申请主键
     * @return 离职申请
     */
    @Override
    public ResignationApplication selectResignationApplicationById(Long id)
    {
        return resignationApplicationMapper.selectResignationApplicationById(id);
    }

    /**
     * 查询离职申请列表
     * 
     * @param resignationApplication 离职申请
     * @return 离职申请
     */
    @Override
    public List<ResignationApplication> selectResignationApplicationList(ResignationApplication resignationApplication)
    {
        return resignationApplicationMapper.selectResignationApplicationList(resignationApplication);
    }

    /**
     * 新增离职申请
     * 
     * @param resignationApplication 离职申请
     * @return 结果
     */
    @Override
    @Transactional
    public int insertResignationApplication(ResignationApplication resignationApplication)
    {
        int rows = resignationApplicationMapper.insertResignationApplication(resignationApplication);
        insertResignationMatter(resignationApplication);
        return rows;
    }

    /**
     * 修改离职申请
     * 
     * @param resignationApplication 离职申请
     * @return 结果
     */
    @Override
    @Transactional
    public int updateResignationApplication(ResignationApplication resignationApplication)
    {
        resignationApplicationMapper.deleteResignationMatterByApplicationId(resignationApplication.getId());
        insertResignationMatter(resignationApplication);
        return resignationApplicationMapper.updateResignationApplication(resignationApplication);
    }

    /**
     * 批量删除离职申请
     * 
     * @param ids 需要删除的离职申请主键
     * @return 结果
     */
    @Transactional
    @Override
    public int deleteResignationApplicationByIds(Long[] ids)
    {
        resignationApplicationMapper.deleteResignationMatterByApplicationIds(ids);
        return resignationApplicationMapper.deleteResignationApplicationByIds(ids);
    }

    /**
     * 删除离职申请信息
     * 
     * @param id 离职申请主键
     * @return 结果
     */
    @Transactional
    @Override
    public int deleteResignationApplicationById(Long id)
    {
        resignationApplicationMapper.deleteResignationMatterByApplicationId(id);
        return resignationApplicationMapper.deleteResignationApplicationById(id);
    }

    /**
     * 新增交接事务信息
     *
     * @param resignationApplication 离职申请对象
     */
    public void insertResignationMatter(ResignationApplication resignationApplication)
    {
        List<ResignationMatter> resignationMatterList = resignationApplication.getResignationMatterList();
        Long id = resignationApplication.getId();
        if (StringUtils.isNotNull(resignationMatterList))
        {
            List<ResignationMatter> list = new ArrayList<ResignationMatter>();
            for (ResignationMatter resignationMatter : resignationMatterList)
            {
                resignationMatter.setApplicationId(id);
                list.add(resignationMatter);
            }
            if (list.size() > 0)
            {
                resignationApplicationMapper.batchResignationMatter(list);
            }
        }
    }


    @Override
    public int updateResignation(ResignationApplication resignationApplication)
    {
        return resignationApplicationMapper.updateResignation(resignationApplication);
    }


    @Override
    public int updateResignation2(ResignationApplication resignationApplication)
    {
        return resignationApplicationMapper.updateResignation2(resignationApplication);
    }




}
