package com.ruoyi.service;

import java.util.List;
import java.util.Map;

import com.ruoyi.domain.LeaveApplication;
import com.ruoyi.domain.dto.BatchUpdateDTO;
import com.ruoyi.domain.dto.EmployeeBalanceDTO;
import io.lettuce.core.dynamic.annotation.Param;

/**
 * 请假申请Service接口
 * 
 * @author hht
 * @date 2025-03-03
 */
public interface ILeaveApplicationService 
{
    /**
     * 查询请假申请
     * 
     * @param id 请假申请主键
     * @return 请假申请
     */
    public LeaveApplication selectLeaveApplicationById(Long id);

    /**
     * 查询请假申请列表
     * 
     * @param leaveApplication 请假申请
     * @return 请假申请集合
     */
    public List<LeaveApplication> selectLeaveApplicationList(LeaveApplication leaveApplication);

    /**
     * 新增请假申请
     * 
     * @param leaveApplication 请假申请
     * @return 结果
     */
    public int insertLeaveApplication(LeaveApplication leaveApplication);

    /**
     * 修改请假申请
     * 
     * @param leaveApplication 请假申请
     * @return 结果
     */
    public int updateLeaveApplication(LeaveApplication leaveApplication);

    /**
     * 批量删除请假申请
     * 
     * @param ids 需要删除的请假申请主键集合
     * @return 结果
     */
    public int deleteLeaveApplicationByIds(Long[] ids);

    /**
     * 删除请假申请信息
     * 
     * @param id 请假申请主键
     * @return 结果
     */
    public int deleteLeaveApplicationById(Long id);


    /**
      * 根据用户id查询用户剩余加班时长
     * @param userId 用户id
     * @return 结果
     */
    EmployeeBalanceDTO selectDeductionOvertimeHoursByUserId(@Param("userId") Long userId);

    /**
     * 更新用户剩余加班时长
     * @param dto 请假申请信息
     *  @return 结果
     */
    int updateOvertimeHoursBalance(EmployeeBalanceDTO dto);

    /**
     * 查询项目经理
     *
     */
    List<String> selectProjectManagers();

    /**
     * 查询总经理
     *
     */
    String  selectGeneralManagerNickName();

    /**
     * 根据节点id和审批状态批量更新请假申请状态
     * @param dto 请假申请信息
     * @return 结果
     */
    int batchUpdateNodeIdAndApprovalStatus(BatchUpdateDTO dto);


}
