package com.ruoyi.service;

import com.ruoyi.domain.Timesheet;
import com.ruoyi.domain.dto.AddTimesheetDTO;
import com.ruoyi.domain.dto.CheckTimesheetDTO;
import com.ruoyi.domain.dto.TimesheetDTO;

import java.util.Date;
import java.util.List;

/**
 * 工时记录Service接口
 *
 * @author ruoyi
 * @date 2025-03-11
 */
public interface ITimesheetService
{
    /**
     * 工时查询--查询个人工时记录
     *
     * @param query 工时记录主键
     * @return 工时记录
     */
    public List<TimesheetDTO>  getProjectTimesheetList(Timesheet query);

    /**
     * 填报工时--查询个人填报
     *
     * @param
     * @return 工时记录
     */
    List<AddTimesheetDTO> getPersonalTimesheet(Long employId);

    /**
     * 填报工时--获取法定节假日
     */
    public List<Date> getWorkingDaysFromAPI();


    /*
    * 工时审批--获取审批
    * */
    public List<CheckTimesheetDTO> getTimesheetCheck(Timesheet query);
    /**
     * 查询工时记录
     *
     * @param id 工时记录主键
     * @return 工时记录
     */
    public Timesheet selectTimesheetById(Long id);

    /**
     * 查询工时记录列表
     *
     * @param timesheet 工时记录
     * @return 工时记录集合
     */
    public List<Timesheet> selectTimesheetList(Timesheet timesheet);

    /**
     * 新增工时记录
     *
     * @param timesheet 工时记录
     * @return 结果
     */
    public int insertTimesheet(Timesheet timesheet);

    /**
     * 批量加入工时记录
     *
     * @param
     * @return 结果
     */
    public int insertTimesheetList(AddTimesheetDTO addTimesheetDTO);

    /**
     * 修改工时记录
     *
     * @param timesheet 工时记录
     * @return 结果
     */
    public int updateTimesheet(Timesheet timesheet);


    /**
     * 按周修改工时记录
     *
     * @return 结果
     */
    public int updateWeekTimesheet(CheckTimesheetDTO checkTimesheetDTO);
    /**
     * 批量删除工时记录
     *
     * @param ids 需要删除的工时记录主键集合
     * @return 结果
     */
    public int deleteTimesheetByIds(Long[] ids);

    /**
     * 删除工时记录信息
     *
     * @param id 工时记录主键
     * @return 结果
     */
    public int deleteTimesheetById(Long id);



   // 自定义方法获取星期几
   public String getDayOfWeek(Date date);


}
