package com.ruoyi.service.impl;

import com.ruoyi.common.core.domain.entity.SysRole;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.common.utils.SecurityUtils;
import com.ruoyi.domain.dto.ApprovalConfigurationDTO;
import com.ruoyi.domain.dto.ApprovalConfigurationNodeDTO;
import com.ruoyi.domain.dto.ApprovalConfigurationNodeItemDTO;
import com.ruoyi.domain.vo.ApprovalConfigurationMainVo;
import com.ruoyi.domain.vo.ApprovalConfigurationRelevanceVo;
import com.ruoyi.mapper.ApprovalConfigurationMapper;
import com.ruoyi.service.IApprovalConfigurationService;
import com.ruoyi.utils.SerialNumberGenerator;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.ArrayList;
import java.util.List;

@Service
public class IApprovalConfigurationServiceImpl implements IApprovalConfigurationService {

    @Autowired
    private SerialNumberGenerator serialNumberGenerator;

    @Autowired
    private ApprovalConfigurationMapper configurationMapper;


    @Override
    public List<ApprovalConfigurationDTO> getALLList(ApprovalConfigurationDTO configurationDTO) {
        return configurationMapper.getALLList(configurationDTO);
    }

    @Override
    public List<SysRole> getAllRole() {
        List<SysRole> allRole = configurationMapper.getAllRole();
        SysRole sysRole = new SysRole();
        //添加本人角色，id为0
        sysRole.setRoleName("本人");
        sysRole.setRoleId(0L);
        allRole.add(0,sysRole);
        return allRole;
    }

    @Override
    @Transactional
    public int insertApprovalConfiguration(ApprovalConfigurationMainVo mainVo) {
        mainVo.setCreateBy(SecurityUtils.getUsername());
        mainVo.setUpdateBy(SecurityUtils.getUsername());
        mainVo.setCreateTime(DateUtils.getNowDate());
        mainVo.setUpdateTime(DateUtils.getNowDate());
        //生成审批编号，根据审批名字首字母
        mainVo.setApprovalNumber(serialNumberGenerator.generateApprovalNumber());
        //先插入主表
        int i = configurationMapper.insertMain(mainVo);

        //再插入子表
        for(ApprovalConfigurationRelevanceVo item : mainVo.getChildrenList()){
            item.setApid(mainVo.getId());
            configurationMapper.insertChild(item);
        }
        return i;
    }

    @Override
    public ApprovalConfigurationMainVo getMainDetailById(Integer id) {
        //先获取主表详情
        ApprovalConfigurationMainVo mainById = configurationMapper.getMainById(id);

        //再获取子表详情
        List<ApprovalConfigurationRelevanceVo> childById = configurationMapper.getChildById(id);
        mainById.setChildrenList(childById);
        return mainById;
    }

    @Override
    @Transactional
    public int updateApprovalConfigurationMain(ApprovalConfigurationMainVo mainVo) {
        mainVo.setUpdateBy(SecurityUtils.getUsername());
        mainVo.setUpdateTime(DateUtils.getNowDate());
        //先更新主表
        int i = configurationMapper.updateMain(mainVo);
        //删除子表数据
        int i1 = configurationMapper.deleteChildById(mainVo.getId());
        //批量插入子表
        for(ApprovalConfigurationRelevanceVo item : mainVo.getChildrenList()){
            item.setApid(mainVo.getId());
            configurationMapper.insertChild(item);
        }
        return i;
    }

    @Override
    @Transactional
    public int delMain(Integer id) {
        //先删除主表
        int i = configurationMapper.delMain(id);
        //再删除子表
        int i1 = configurationMapper.deleteChildById(id);
        return i1;
    }

    @Override
    public ApprovalConfigurationNodeDTO getNodeList(Integer id) {
        List<ApprovalConfigurationNodeItemDTO> nodeList = configurationMapper.getNodeList(id);
        ApprovalConfigurationNodeDTO nodeDTO = new ApprovalConfigurationNodeDTO();
        List<ApprovalConfigurationNodeItemDTO> itemDTOS = new ArrayList<ApprovalConfigurationNodeItemDTO>();
        for(ApprovalConfigurationNodeItemDTO item : nodeList){
            ApprovalConfigurationNodeItemDTO itemDTO = new ApprovalConfigurationNodeItemDTO();
            itemDTO.setNodeId(item.getNodeId());
            itemDTO.setRoleId(item.getRoleId());
            itemDTO.setRoleName(item.getRoleName());
            itemDTOS.add(itemDTO);
        }

        nodeDTO.setNodeList(itemDTOS);
        nodeDTO.setApprovalName(nodeList.get(0).getApprovalName());
        nodeDTO.setApproveType(nodeList.get(0).getApproveType());
        nodeDTO.setRemark(nodeList.get(0).getRemark());
        return nodeDTO;
    }
}
