package com.ruoyi.service.impl;

import java.math.BigDecimal;
import java.util.*;

import com.ruoyi.domain.dto.BatchUpdateDTO;
import com.ruoyi.domain.dto.EmployeeBalanceDTO;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.mapper.LeaveApplicationMapper;
import com.ruoyi.domain.LeaveApplication;
import com.ruoyi.service.ILeaveApplicationService;

/**
 * 请假申请Service业务层处理
 * 
 * @author hht
 * @date 2025-03-03
 */
@Service
public class LeaveApplicationServiceImpl implements ILeaveApplicationService 
{
    @Autowired
    private LeaveApplicationMapper leaveApplicationMapper;

    /**
     * 查询请假申请
     * 
     * @param id 请假申请主键
     * @return 请假申请
     */
    @Override
    public LeaveApplication selectLeaveApplicationById(Long id)
    {
        return leaveApplicationMapper.selectLeaveApplicationById(id);
    }

    /**
     * 查询请假申请列表
     * 
     * @param leaveApplication 请假申请
     * @return 请假申请
     */
    @Override
    public List<LeaveApplication> selectLeaveApplicationList(LeaveApplication leaveApplication)
    {
        return leaveApplicationMapper.selectLeaveApplicationList(leaveApplication);
    }

    /**
     * 新增请假申请
     * 
     * @param leaveApplication 请假申请
     * @return 结果
     */
    @Override
    public int insertLeaveApplication(LeaveApplication leaveApplication)
    {
        leaveApplication.setNodeId(111);
        // 生成请假单号
        leaveApplication.setLeaveId(generateLeaveId());
        // 生成请假日期
        leaveApplication.setRequestDate(new Date());
        return leaveApplicationMapper.insertLeaveApplication(leaveApplication);
    }
   // 生成请假单号
    private String generateLeaveId() {
        // 生成时间戳部分
        String timestamp = Long.toString(System.currentTimeMillis(), 16);
        // 生成随机数部分
        Random random = new Random();
        String randomNum = Integer.toHexString(random.nextInt(10000)).substring(0, 2);
        return randomNum + timestamp;
    }

    /**
     * 修改请假申请
     * 
     * @param leaveApplication 请假申请
     * @return 结果
     */
    @Override
    public int updateLeaveApplication(LeaveApplication leaveApplication)
    {
        return leaveApplicationMapper.updateLeaveApplication(leaveApplication);
    }

    /**
     * 批量删除请假申请
     * 
     * @param ids 需要删除的请假申请主键
     * @return 结果
     */
    @Override
    public int deleteLeaveApplicationByIds(Long[] ids)
    {
        return leaveApplicationMapper.deleteLeaveApplicationByIds(ids);
    }

    /**
     * 删除请假申请信息
     * 
     * @param id 请假申请主键
     * @return 结果
     */
    @Override
    public int deleteLeaveApplicationById(Long id)
    {
        return leaveApplicationMapper.deleteLeaveApplicationById(id);
    }

    /**
     * 根据用户ID查询总的的加班小时数
     * @param userId
     * @return
     */
    @Override

    public EmployeeBalanceDTO selectDeductionOvertimeHoursByUserId(Long userId) {
        return leaveApplicationMapper.selectDeductionOvertimeHoursByUserId(userId);
    }

    /**
     * 更新员工的加班小时数余额
     * @param dto 包含加班小时数余额和员工ID的DTO对象
     * @return 更新结果
     */
    @Override
    public int updateOvertimeHoursBalance(EmployeeBalanceDTO dto) {
        return leaveApplicationMapper.updateOvertimeHoursBalance(dto);
    }

    /**
     * 查询项目经理列表
     * @return
     */
    @Override
    public List<String> selectProjectManagers() {
        return leaveApplicationMapper.selectProjectManagers();
    }

    /**
     * 查询总经理的昵称
     * @return
     */
    @Override
    public String  selectGeneralManagerNickName(){
        return leaveApplicationMapper.selectGeneralManagerNickName();
    }

    /**
     * 批量更新节点ID和审批状态
     * @param dto 包含节点ID和审批状态的DTO对象
     * @return 更新结果
     */
    @Override
    public int batchUpdateNodeIdAndApprovalStatus(BatchUpdateDTO dto) {
        return leaveApplicationMapper.batchUpdateNodeIdAndApprovalStatus(dto);
    }
}
