package com.ruoyi.service.impl;

import java.math.BigDecimal;
import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.*;

import com.ruoyi.domain.EmployeeBalance;
import com.ruoyi.domain.dto.OvertimeApplicationBatchDTO;
import com.ruoyi.mapper.EmployeeBalanceMapper;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.mapper.OvertimeApplicationMapper;
import com.ruoyi.domain.OvertimeApplication;
import com.ruoyi.service.IOvertimeApplicationService;

/**
 * 加班申请Service业务层处理
 * 
 * @author hht
 * @date 2025-03-06
 */
@Service
public class OvertimeApplicationServiceImpl implements IOvertimeApplicationService 
{
    @Autowired
    private OvertimeApplicationMapper overtimeApplicationMapper;
    @Autowired
    private EmployeeBalanceMapper employeeBalanceMapper;


    /**
     * 查询加班申请
     * 
     * @param id 加班申请主键
     * @return 加班申请
     */
    @Override
    public OvertimeApplication selectOvertimeApplicationById(Long id)
    {
        return overtimeApplicationMapper.selectOvertimeApplicationById(id);
    }

    /**
     * 查询加班申请列表
     * 
     * @param overtimeApplication 加班申请
     * @return 加班申请
     */
    @Override
    public List<OvertimeApplication> selectOvertimeApplicationList(OvertimeApplication overtimeApplication)
    {
        return overtimeApplicationMapper.selectOvertimeApplicationList(overtimeApplication);
    }

    @Override
    public Long getUserIdByNickName(String nickName) {
        return overtimeApplicationMapper.getUserIdByNickName(nickName);
    }

    /**
     * 新增加班申请
     * 
     * @param overtimeApplication 加班申请
     * @return 结果
     */
    @Override
    public int insertOvertimeApplication(OvertimeApplication overtimeApplication)
    {    // 生成加班单号
        overtimeApplication.setOvertimeId(generateLeaveId());

        return overtimeApplicationMapper.insertOvertimeApplication(overtimeApplication);
    }
    // 生成加假单号
    private String generateLeaveId() {
        // 生成时间戳部分
        String timestamp = Long.toString(System.currentTimeMillis(), 16);
        // 生成随机数部分
        Random random = new Random();
        String randomNum = Integer.toHexString(random.nextInt(10000)).substring(0, 2);
        return randomNum + timestamp;
    }
     // 插入员工余额
    private void updateOrInsertEmployeeBalance(Long employeeId, BigDecimal overtimeHours) {
        if (employeeId == null) {
            throw new IllegalArgumentException("employeeId cannot be null");
        }
        EmployeeBalance employeeBalance = employeeBalanceMapper.selectEmployeeBalanceByEmployeeId(employeeId);
        if (employeeBalance == null) {
            // 如果没有记录，则插入新记录
            EmployeeBalance newEmployeeBalance = new EmployeeBalance();
            newEmployeeBalance.setEmployeeId(employeeId);
            newEmployeeBalance.setOvertimeHoursBalance(overtimeHours);
            employeeBalanceMapper.insertEmployeeBalance(newEmployeeBalance);
        } else {
            // 如果已有记录，则更新记录
            employeeBalanceMapper.updateEmployeeBalance(employeeId, overtimeHours);
        }
    }

    // 更新员工余额
    private void updateEmployeeBalance(Long employeeId, BigDecimal difference) {
        EmployeeBalance employeeBalance = employeeBalanceMapper.selectEmployeeBalanceByEmployeeId(employeeId);
        if (employeeBalance == null) {
            // 如果没有记录，则插入新记录
            EmployeeBalance newEmployeeBalance = new EmployeeBalance();
            newEmployeeBalance.setEmployeeId(employeeId);
            newEmployeeBalance.setOvertimeHoursBalance(difference);
            employeeBalanceMapper.insertEmployeeBalance(newEmployeeBalance);
        } else {
            // 如果已有记录，则更新记录
            employeeBalanceMapper.updateEmployeeBalance(employeeId, difference);
        }
    }



    /**
     * 修改加班申请
     * 
     * @param overtimeApplication 加班申请
     * @return 结果
     */
    @Override
    public int updateOvertimeApplication(OvertimeApplication overtimeApplication)
    {

        System.out.println("我是修改的加班申请数据"+ overtimeApplication );
        // 获取原始加班申请记录
        OvertimeApplication originalApplication = selectOvertimeApplicationById(overtimeApplication.getId());
        System.out.println("我是原始的加班申请数据"  + originalApplication );
        if (originalApplication == null) {
            throw new RuntimeException("加班申请记录不存在，ID: " + overtimeApplication.getId());
        }

        // 计算加班时长的变化
        BigDecimal originalOvertimeHours = new BigDecimal(originalApplication.getOvertimeHours());
        BigDecimal newOvertimeHours = new BigDecimal(overtimeApplication.getOvertimeHours());
        BigDecimal difference = newOvertimeHours.subtract(originalOvertimeHours);

        // 更新员工余额
        updateEmployeeBalance(originalApplication.getEmployeeId(), difference);

        // 更新加班申请记录
        return overtimeApplicationMapper.updateOvertimeApplication(overtimeApplication);
    }

    /**
     * 批量删除加班申请
     * 
     * @param ids 需要删除的加班申请主键
     * @return 结果
     */
    @Override
    public int deleteOvertimeApplicationByIds(Long[] ids)
    {
        return overtimeApplicationMapper.deleteOvertimeApplicationByIds(ids);
    }

    /**
     * 删除加班申请信息
     * 
     * @param id 加班申请主键
     * @return 结果
     */
    @Override
    public int deleteOvertimeApplicationById(Long id)
    {
        return overtimeApplicationMapper.deleteOvertimeApplicationById(id);
    }


    /**
     * 批量新增加班申请
     *
     * @param batchRequest 加班申请
     * @return 结果
     */
    @Override
    public int insertOvertimeApplicationBatch(OvertimeApplicationBatchDTO batchRequest)
    {
        List<OvertimeApplication> list = new ArrayList<>();
        // 计算上个月的归属月份
        Calendar cal = Calendar.getInstance();
        cal.add(Calendar.MONTH, -1);
        String yearMonth = String.format("%04d", cal.get(Calendar.YEAR)) + "-" + String.format("%02d", cal.get(Calendar.MONTH) + 1);
        for (OvertimeApplicationBatchDTO.OvertimeDetail detail : batchRequest.getEmployees()) {
            OvertimeApplication entity = new OvertimeApplication();

            // 公共字段
            entity.setProject(batchRequest.getProject());
            entity.setDivisionLeader(batchRequest.getDivisionLeader());
            entity.setProjectLeader(batchRequest.getProjectLeader());
            // 单条记录字段
            long userId = overtimeApplicationMapper.getUserIdByNickName(detail.getUname());
            entity.setEmployeeId(userId);
            entity.setUname(detail.getUname());
            entity.setOvertimeHours(detail.getOvertimeHours());
            entity.setRequestDate(detail.getRequestDate());

            // 设置归属月份为上个月的月份
            entity.setYearMonth(yearMonth);
            // 生成加班单号
            entity.setOvertimeId(generateLeaveId());
            // 其他字段，如 createdTime, updatedTime 等
            entity.setCreatedTime(new Date());
            // 更新或插入员工余额
            updateOrInsertEmployeeBalance(userId, new BigDecimal(detail.getOvertimeHours()));

            list.add(entity);
        }

        // 循环插入
        int count = 0;
        for (OvertimeApplication oa : list) {
            count += overtimeApplicationMapper.insertOvertimeApplication(oa);
        }
        return count;
    }
}
