package com.ruoyi.service.impl;

import java.io.IOException;
import java.math.BigDecimal;
import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.*;
import java.util.stream.Collectors;

import com.fasterxml.jackson.core.JsonProcessingException;
import com.fasterxml.jackson.core.type.TypeReference;
import com.fasterxml.jackson.databind.ObjectMapper;
import com.ruoyi.common.core.domain.entity.SysRole;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.domain.dto.*;
import com.ruoyi.service.ITimesheetService;
import com.ruoyi.system.domain.ProjectManage;
import com.ruoyi.system.domain.ProjectMember;
import com.ruoyi.system.mapper.*;
import org.apache.http.client.methods.CloseableHttpResponse;
import org.apache.http.client.methods.HttpGet;
import org.apache.http.impl.client.CloseableHttpClient;
import org.apache.http.impl.client.HttpClients;
import org.apache.http.util.EntityUtils;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.mapper.TimesheetMapper;
import com.ruoyi.domain.Timesheet;

/**
 * 工时记录Service业务层处理
 * 
 * @author ruoyi
 * @date 2025-02-28
 */
@Service
public class TimesheetServiceImpl implements ITimesheetService
{
    @Autowired
    private TimesheetMapper timesheetMapper;

    @Autowired
    private SysUserMapper sysUserMapper;

    @Autowired
    private SysUserRoleMapper sysUserRoleMapper;

    @Autowired
    private ProjectManageMapper projectManageMapper;

    @Autowired
    private ProjectMemberMapper projectMemberMapper;

    private static final String API_URL = "https://api.jiejiariapi.com/v1/workdays/{year}";

    @Override
    public List<TimesheetDTO> getProjectTimesheetList(Timesheet query) {
        // 获取用户角色
        List<Long> roles = sysUserRoleMapper.selectRoleIdsByUserId(query.getEmployId());

        if (roles.contains(2L)) {
            query.setManagerName(query.getManagerName()); // 确保传递 managerName
            List<Timesheet> timesheets = timesheetMapper.selectTimesheetGroupByProject(query);

            Map<String, TimesheetDTO> projectMap = new LinkedHashMap<>();

            for (Timesheet timesheet : timesheets) {
                String projectNumber = timesheet.getProjectNumber();

                if (!projectMap.containsKey(projectNumber)) {
                    TimesheetDTO dto = new TimesheetDTO();
                    dto.setProjectNumber(timesheet.getProjectNumber());
                    dto.setProjectName(timesheet.getProjectName());
                    dto.setManagerName(timesheet.getManagerName());
                    dto.setDepartmentLeaderName(timesheet.getDepartmentLeaderName());
                    dto.setTotalHours(BigDecimal.ZERO); // 初始化 totalHours 为 0
                    dto.setWorkDetails(new ArrayList<>());
                    projectMap.put(projectNumber, dto);
                }

                TimesheetDTO dto = projectMap.get(projectNumber);
                // 检查是否已存在相同的 workTime 和 hours
                boolean isDuplicate = dto.getWorkDetails().stream()
                        .anyMatch(workDetail -> workDetail.getWorkTime().equals(timesheet.getWorkTime())
                                && workDetail.getHours().equals(timesheet.getHours()));
                if (!isDuplicate) {
                    dto.getWorkDetails().add(new WorkDetailDTO(
                            timesheet.getWorkTime(),
                            timesheet.getHours()
                    ));
                    // 累加 totalHours
                    dto.setTotalHours(dto.getTotalHours().add(timesheet.getHours()));
                }
            }

            // 计算 startTime 和 endTime
            for (TimesheetDTO dto : projectMap.values()) {
                if (!dto.getWorkDetails().isEmpty()) {
                    // 找到最早和最晚的时间
                    Date startTime = dto.getWorkDetails().stream()
                            .map(WorkDetailDTO::getWorkTime)
                            .min(Date::compareTo)
                            .orElse(null);
                    Date endTime = dto.getWorkDetails().stream()
                            .map(WorkDetailDTO::getWorkTime)
                            .max(Date::compareTo)
                            .orElse(null);

                    dto.setStartTime(startTime);
                    dto.setEndTime(endTime);
                }
            }

            return new ArrayList<>(projectMap.values());
        }else if (roles.contains(1L)){
            query.setEmployId(null);
            query.setManagerName(query.getManagerName()); // 确保传递 managerName
            List<Timesheet> timesheets = timesheetMapper.selectTimesheetGroupByProject(query);

            Map<String, TimesheetDTO> projectMap = new LinkedHashMap<>();

            for (Timesheet timesheet : timesheets) {
                String projectNumber = timesheet.getProjectNumber();

                if (!projectMap.containsKey(projectNumber)) {
                    TimesheetDTO dto = new TimesheetDTO();
                    dto.setProjectNumber(timesheet.getProjectNumber());
                    dto.setProjectName(timesheet.getProjectName());
                    dto.setManagerName(timesheet.getManagerName());
                    dto.setDepartmentLeaderName(timesheet.getDepartmentLeaderName());
                    dto.setTotalHours(BigDecimal.ZERO); // 初始化 totalHours 为 0
                    dto.setWorkDetails(new ArrayList<>());
                    projectMap.put(projectNumber, dto);
                }

                TimesheetDTO dto = projectMap.get(projectNumber);
                // 检查是否已存在相同的 workTime 和 hours
                boolean isDuplicate = dto.getWorkDetails().stream()
                        .anyMatch(workDetail -> workDetail.getWorkTime().equals(timesheet.getWorkTime())
                                && workDetail.getHours().equals(timesheet.getHours()));
                if (!isDuplicate) {
                    dto.getWorkDetails().add(new WorkDetailDTO(
                            timesheet.getWorkTime(),
                            timesheet.getHours()
                    ));
                    // 累加 totalHours
                    dto.setTotalHours(dto.getTotalHours().add(timesheet.getHours()));
                }
            }

            // 计算 startTime 和 endTime
            for (TimesheetDTO dto : projectMap.values()) {
                if (!dto.getWorkDetails().isEmpty()) {
                    // 找到最早和最晚的时间
                    Date startTime = dto.getWorkDetails().stream()
                            .map(WorkDetailDTO::getWorkTime)
                            .min(Date::compareTo)
                            .orElse(null);
                    Date endTime = dto.getWorkDetails().stream()
                            .map(WorkDetailDTO::getWorkTime)
                            .max(Date::compareTo)
                            .orElse(null);

                    dto.setStartTime(startTime);
                    dto.setEndTime(endTime);
                }
            }

            return new ArrayList<>(projectMap.values());
        }else if (roles.contains(100L)|| roles.contains(104L)){
            if (roles.contains(100L)){
                query.setProjectManagerId(query.getEmployId());
                query.setEmployId(null);
            } else if (roles.contains(104L)) {
                query.setDepartmentLeaderId(query.getEmployId());
                query.setEmployId(null);
            }
            query.setManagerName(query.getManagerName()); // 确保传递 managerName
            System.out.println(query);
            List<Timesheet> timesheets = timesheetMapper.selectTimesheetGroupByProject(query);

            Map<String, TimesheetDTO> projectMap = new LinkedHashMap<>();

            for (Timesheet timesheet : timesheets) {
                String projectNumber = timesheet.getProjectNumber();

                if (!projectMap.containsKey(projectNumber)) {
                    TimesheetDTO dto = new TimesheetDTO();
                    dto.setProjectNumber(timesheet.getProjectNumber());
                    dto.setProjectName(timesheet.getProjectName());
                    dto.setManagerName(timesheet.getManagerName());
                    dto.setDepartmentLeaderName(timesheet.getDepartmentLeaderName());
                    dto.setTotalHours(BigDecimal.ZERO); // 初始化 totalHours 为 0
                    dto.setWorkDetails(new ArrayList<>());
                    projectMap.put(projectNumber, dto);
                }

                TimesheetDTO dto = projectMap.get(projectNumber);
                // 检查是否已存在相同的 workTime 和 hours
                boolean isDuplicate = dto.getWorkDetails().stream()
                        .anyMatch(workDetail -> workDetail.getWorkTime().equals(timesheet.getWorkTime())
                                && workDetail.getHours().equals(timesheet.getHours()));
                if (!isDuplicate) {
                    dto.getWorkDetails().add(new WorkDetailDTO(
                            timesheet.getWorkTime(),
                            timesheet.getHours()
                    ));
                    // 累加 totalHours
                    dto.setTotalHours(dto.getTotalHours().add(timesheet.getHours()));
                }
            }

            // 计算 startTime 和 endTime
            for (TimesheetDTO dto : projectMap.values()) {
                if (!dto.getWorkDetails().isEmpty()) {
                    // 找到最早和最晚的时间
                    Date startTime = dto.getWorkDetails().stream()
                            .map(WorkDetailDTO::getWorkTime)
                            .min(Date::compareTo)
                            .orElse(null);
                    Date endTime = dto.getWorkDetails().stream()
                            .map(WorkDetailDTO::getWorkTime)
                            .max(Date::compareTo)
                            .orElse(null);

                    dto.setStartTime(startTime);
                    dto.setEndTime(endTime);
                }
            }

            return new ArrayList<>(projectMap.values());
        }
        else {
            return new ArrayList<>();
        }
    }



    /*
     * 填报工时--获取法定工作日
     */
    @Override
    public List<Date> getWorkingDaysFromAPI() {
        // 获取当前年份
        Calendar calendar = Calendar.getInstance();
        int currentYear = calendar.get(Calendar.YEAR);

        // 动态生成 URL
        String apiUrl = API_URL.replace("{year}", String.valueOf(currentYear));

        List<Date> workingDays = new ArrayList<>();
        try (CloseableHttpClient httpClient = HttpClients.createDefault()) {
            HttpGet request = new HttpGet(apiUrl);
            try (CloseableHttpResponse response = httpClient.execute(request)) {
                if (response.getStatusLine().getStatusCode() == 200) {
                    String jsonResult = EntityUtils.toString(response.getEntity());
                    ObjectMapper objectMapper = new ObjectMapper();
                    // 添加日志输出，方便调试
                    System.out.println("API Response: " + jsonResult);
                    try {
                        Map<String, WorkingDayDTO> apiResponse = objectMapper.readValue(jsonResult, new TypeReference<Map<String, WorkingDayDTO>>() {});
                        SimpleDateFormat sdf = new SimpleDateFormat("yyyy-MM-dd");
                        for (Map.Entry<String, WorkingDayDTO> entry : apiResponse.entrySet()) {
                            WorkingDayDTO workingDay = entry.getValue();
                            if (!workingDay.isOffDay()) {
                                Date date = sdf.parse(workingDay.getDate().toString());
                                workingDays.add(date);
                            }
                        }
                    } catch (JsonProcessingException e) {
                        e.printStackTrace();
                        // 处理 JSON 格式错误
                        System.err.println("JSON Parsing Error: " + e.getMessage());
                    } catch (ParseException e) {
                        e.printStackTrace();
                        // 处理日期解析错误
                        System.err.println("Date Parsing Error: " + e.getMessage());
                    }
                } else {
                    System.err.println("API Request Failed with Status Code: " + response.getStatusLine().getStatusCode());
                }
            } catch (IOException e) {
                e.printStackTrace();
                // 处理 IO 异常
                System.err.println("IO Error: " + e.getMessage());
            }
        } catch (IOException e) {
            e.printStackTrace();
            // 处理 IO 异常
            System.err.println("IO Error: " + e.getMessage());
        }
        return workingDays;
    }

    /*
     * 工时审批--获取审批
     * */
    @Override
    public List<CheckTimesheetDTO> getTimesheetCheck(Timesheet query) {

        String managerName = sysUserMapper.selectUserById(query.getProjectManagerId()).getNickName();

        // 查询该员工的所有工时记录
        List<Timesheet> timesheets = timesheetMapper.selectTimesheetByManagerId(query);

        // 按项目分组，再按周分组
        Map<String, Map<String, List<Timesheet>>> projectWeeklyTimesheets = new HashMap<>();

        for (Timesheet timesheet : timesheets) {
            String projectNumber = timesheet.getProjectNumber();
            String weekRange = getWeekRange(timesheet.getWorkTime()); // 获取周范围

            projectWeeklyTimesheets
                    .computeIfAbsent(projectNumber, k -> new HashMap<>())
                    .computeIfAbsent(weekRange, k -> new ArrayList<>())
                    .add(timesheet);
        }

        List<CheckTimesheetDTO> checkTimesheetList = new ArrayList<>();

        for (Map.Entry<String, Map<String, List<Timesheet>>> projectEntry : projectWeeklyTimesheets.entrySet()) {
            String projectNumber = projectEntry.getKey();
            Map<String, List<Timesheet>> weeklyTimesheets = projectEntry.getValue();

            CheckTimesheetDTO checkTimesheetDTO = new CheckTimesheetDTO();
            checkTimesheetDTO.setProjectNumber(projectNumber);
            checkTimesheetDTO.setProjectName(weeklyTimesheets.values().iterator().next().get(0).getProjectName()); // 修改为当前 timesheet 的 projectName

            List<EmployeeTimesheetDTO> employeeTimesheetList = new ArrayList<>();

            for (Map.Entry<String, List<Timesheet>> weekEntry : weeklyTimesheets.entrySet()) {
                String weekRange = weekEntry.getKey();
                List<Timesheet> timesheetList = weekEntry.getValue();

                EmployeeTimesheetDTO employeeTimesheetDTO = new EmployeeTimesheetDTO();
                employeeTimesheetDTO.setEmployId(timesheetList.get(0).getEmployId());
                employeeTimesheetDTO.setEmployName(timesheetList.get(0).getEmployName());
                employeeTimesheetDTO.setApprovalState(timesheetList.get(0).getApprovalState());
                employeeTimesheetDTO.setApprovalNote(timesheetList.get(0).getApprovalNote());
                employeeTimesheetDTO.setTotalHours(BigDecimal.ZERO);

                List<WorkDetailDTO> workDetailList = new ArrayList<>();

                // 找到最早的 workTime 和最晚的 workTime
                Date startTime = timesheetList.stream()
                        .map(Timesheet::getWorkTime)
                        .min(Date::compareTo)
                        .orElse(null);
                Date endTime = timesheetList.stream()
                        .map(Timesheet::getWorkTime)
                        .max(Date::compareTo)
                        .orElse(null);

                employeeTimesheetDTO.setStartTime(startTime);
                employeeTimesheetDTO.setEndTime(endTime);

                for (Timesheet timesheet : timesheetList) {
                    WorkDetailDTO workDetailDTO = new WorkDetailDTO(timesheet.getWorkTime(), timesheet.getHours());
                    workDetailDTO.setId(timesheet.getId());
                    workDetailDTO.setWorkTime(timesheet.getWorkTime());
                    workDetailDTO.setHours(timesheet.getHours());

                    workDetailList.add(workDetailDTO);

                    // 累加总工时
                    employeeTimesheetDTO.setTotalHours(employeeTimesheetDTO.getTotalHours().add(timesheet.getHours()));
                }

                employeeTimesheetDTO.setWorkDetailList(workDetailList);
                employeeTimesheetList.add(employeeTimesheetDTO);
            }

            checkTimesheetDTO.setEmployeeTimesheetList(employeeTimesheetList);
            checkTimesheetList.add(checkTimesheetDTO);
        }

        return checkTimesheetList;
    }
    /**
     * 填报工时--获取填报列表
     * @return 个人工时记录列表
     */
    @Override
    public List<AddTimesheetDTO> getPersonalTimesheet(Long employId) {
        String employName = sysUserMapper.selectUserById(employId).getNickName();

        // 获取当前日期和本周的起始日期（周一）与结束日期（周日）
        Calendar calendar = Calendar.getInstance();
        calendar.set(Calendar.DAY_OF_WEEK, Calendar.SUNDAY);
        Date startOfWeek = calendar.getTime();
        calendar.add(Calendar.DAY_OF_WEEK, 6);
        Date endOfWeek = calendar.getTime();

        // 获取所有工作日
        List<Date> workingDays = getWorkingDaysFromAPI();

        // 过滤本周的工作日
        List<Date> thisWeekWorkingDays = workingDays.stream()
                .filter(workingDay -> !workingDay.before(startOfWeek) && !workingDay.after(endOfWeek))
                .collect(Collectors.toList());
        //System.out.println("This Week Working Days: " + thisWeekWorkingDays);

        // 获取员工的项目列表
        ProjectMember projectMember = new ProjectMember();
        projectMember.setUserId(employId);
        List<ProjectMember> projectMembers = projectMemberMapper.selectProjectMemberList(projectMember);
        List<ProjectManage> projects = projectMembers.stream()
                .map(member -> projectManageMapper.selectPersonalProjectManageList(member.getProjectId()))
                .flatMap(List::stream) // 将嵌套的List<ProjectManage>扁平化为Stream<ProjectManage>
                .filter(Objects::nonNull) // 过滤掉可能为 null 的结果
                .distinct() // 去重
                .collect(Collectors.toList());
        List<AddTimesheetDTO> addTimesheetList = new ArrayList<>();

        // 遍历每个项目
        for (ProjectManage project : projects) {
            AddTimesheetDTO addTimesheetDTO = new AddTimesheetDTO();
            addTimesheetDTO.setEmployId(employId);
            addTimesheetDTO.setEmployName(employName);
            addTimesheetDTO.setProjectNumber(project.getProjectNumber());
            addTimesheetDTO.setProjectName(project.getProjectName());
            addTimesheetDTO.setManagerId(project.getProjectManagerId());
            addTimesheetDTO.setManagerName(project.getProjectManagerName());
            addTimesheetDTO.setDepartmentLeaderId(project.getDepartmentLeaderId());
            addTimesheetDTO.setDepartmentLeaderName(project.getDepartmentLeaderName());
            addTimesheetDTO.setApprovalState("2"); // 默认审批状态
            addTimesheetDTO.setApprovalNote(""); // 默认审批备注
            addTimesheetDTO.setTotalHours(BigDecimal.ZERO); // 初始化总工时为0

            List<AddWorkDTO> addWorkList = new ArrayList<>();

            // 遍历本周的每个工作日
            for (Date workTime : thisWeekWorkingDays) {
              //  System.out.println("workTime Day: " + workTime+"//////////////////////");
                // 查询该工作日的工时记录
                List<Timesheet> timesheets = timesheetMapper.selectPersonalTimesheet(employId, workTime, project.getProjectNumber());

                AddWorkDTO addWorkDTO = new AddWorkDTO();
                addWorkDTO.setWorkTime(workTime);
                addWorkDTO.setWorkWeek(getDayOfWeek(workTime)); // 获取星期几

                if (!timesheets.isEmpty()) {
                    // 如果有工时记录，设置工时并从第一条记录中获取审批状态和备注
                    addWorkDTO.setHours(timesheets.get(0).getHours());
                    addTimesheetDTO.setApprovalState(timesheets.get(0).getApprovalState());
                    addTimesheetDTO.setApprovalNote(timesheets.get(0).getApprovalNote());
                    // 累加总工时
                    addTimesheetDTO.setTotalHours(addTimesheetDTO.getTotalHours().add(timesheets.get(0).getHours()));
                } else {
                    // 如果没有工时记录，设置工时为0，并保留默认审批状态和备注
                    addWorkDTO.setHours(BigDecimal.ZERO);
                }

                addWorkList.add(addWorkDTO);
            }

            addTimesheetDTO.setAddWorkList(addWorkList);
            addTimesheetList.add(addTimesheetDTO);
        }

        return addTimesheetList;
    }





    /**
     * 查询工时记录
     * 
     * @param id 工时记录主键
     * @return 工时记录
     */
    @Override
    public Timesheet selectTimesheetById(Long id)
    {
        return timesheetMapper.selectTimesheetById(id);
    }

    /**
     * 查询工时记录列表
     *
     * @param timesheet 工时记录
     * @return 工时记录
     */
    @Override
    public List<Timesheet> selectTimesheetList(Timesheet timesheet)
    {
        return timesheetMapper.selectTimesheetList(timesheet);
    }



    /**
     * 新增工时记录
     * 
     * @param timesheet 工时记录
     * @return 结果
     */
    @Override
    public int insertTimesheet(Timesheet timesheet)
    {
        timesheet.setCreateTime(DateUtils.getNowDate());
        return timesheetMapper.insertTimesheet(timesheet);
    }

    /**
     * 批量插入工时记录
     *
     */
    @Override
    public int insertTimesheetList(AddTimesheetDTO addTimesheetDTO) {
        int result = 0;
        // 检查 addWorkList 是否为空
        if (addTimesheetDTO.getAddWorkList() == null || addTimesheetDTO.getAddWorkList().isEmpty()) {
            throw new IllegalArgumentException("addWorkList cannot be empty");
        }
        for (AddWorkDTO addWorkDTO : addTimesheetDTO.getAddWorkList()) {
            Timesheet timesheet = new Timesheet();
            timesheet.setEmployId(addTimesheetDTO.getEmployId());
            timesheet.setEmployName(addTimesheetDTO.getEmployName());
            timesheet.setProjectNumber(addTimesheetDTO.getProjectNumber());
            timesheet.setProjectName(addTimesheetDTO.getProjectName());
            timesheet.setProjectManagerId(addTimesheetDTO.getManagerId());
            timesheet.setDepartmentLeaderId(addTimesheetDTO.getDepartmentLeaderId());
            timesheet.setHours(addWorkDTO.getHours());
            timesheet.setWorkTime(addWorkDTO.getWorkTime());
            timesheet.setWorkWeek(addWorkDTO.getWorkWeek());
            timesheet.setApprovalState("3");
            timesheet.setApprovalNote(addTimesheetDTO.getApprovalNote());
            timesheet.setDeleted(Timesheet.NO_DELETE);
            result += timesheetMapper.insertTimesheet(timesheet);
        }

        return result;
    }

    /**
     * 修改工时记录
     * 
     * @param timesheet 工时记录
     * @return 结果
     */
    @Override
    public int updateTimesheet(Timesheet timesheet)
    {
        timesheet.setUpdateTime(DateUtils.getNowDate());
        return timesheetMapper.updateTimesheet(timesheet);
    }

    /**
     *一键驳回/通过
     *
     * @return 结果
     */
    @Override
    public int updateWeekTimesheet(CheckTimesheetDTO checkTimesheetDTO) {
        int result = 0;

        // 添加空值检查
        if (checkTimesheetDTO.getEmployeeTimesheetList() == null) {
            throw new IllegalArgumentException("EmployeeTimesheetList cannot be null");
        }

        for (EmployeeTimesheetDTO employeeTimesheetDTO : checkTimesheetDTO.getEmployeeTimesheetList()) {
            // 检查 workDetailList 是否为空
            if (employeeTimesheetDTO.getWorkDetailList() != null) {
                for (WorkDetailDTO workDetailDTO : employeeTimesheetDTO.getWorkDetailList()) {
                    Timesheet timesheet = new Timesheet();
                    timesheet.setId(workDetailDTO.getId());
                    timesheet.setApprovalState(employeeTimesheetDTO.getApprovalState()); // 设置审批状态
                    timesheet.setApprovalNote(employeeTimesheetDTO.getApprovalNote()); // 设置审批备注
                    timesheet.setUpdateTime(DateUtils.getNowDate()); // 设置更新时间
                    result += timesheetMapper.updateTimesheet(timesheet); // 更新工时记录
                }
            }
        }

        // 如果没有记录被更新，抛出异常或返回特定错误信息
        if (result == 0) {
            throw new RuntimeException("无可审批的申请");
        }

        return result;
    }

    /**
     * 批量删除工时记录
     * 
     * @param ids 需要删除的工时记录主键
     * @return 结果
     */
    @Override
    public int deleteTimesheetByIds(Long[] ids)
    {
        return timesheetMapper.deleteTimesheetByIds(ids);
    }

    /**
     * 删除工时记录信息
     * 
     * @param id 工时记录主键
     * @return 结果
     */
    @Override
    public int deleteTimesheetById(Long id)
    {
        return timesheetMapper.deleteTimesheetById(id);
    }

    @Override
    public String getDayOfWeek(Date date) {
        Calendar calendar = Calendar.getInstance();
        calendar.setTime(date);
        int dayOfWeek = calendar.get(Calendar.DAY_OF_WEEK);
        // 调整数组顺序，使其与 Calendar.DAY_OF_WEEK 的值对应
        String[] days = new String[]{"周日", "周一", "周二", "周三", "周四", "周五", "周六"};
        return days[dayOfWeek - 1]; // 因为数组索引从0开始，所以需要减1
    }

    private String getWeekRange(Date date) {
        Calendar calendar = Calendar.getInstance();
        calendar.setTime(date);
        calendar.set(Calendar.DAY_OF_WEEK, Calendar.MONDAY); // 设置为一周的起始日（周一）
        Date startOfWeek = calendar.getTime();
        calendar.add(Calendar.DAY_OF_WEEK, 6); // 设置为一周的结束日（周日）
        Date endOfWeek = calendar.getTime();

        SimpleDateFormat sdf = new SimpleDateFormat("yyyy/MM/dd");
        return sdf.format(startOfWeek) + "-" + sdf.format(endOfWeek);
    }
}
